@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: arg.c,v 1.43 2004/03/10 23:42:49 abe Exp $";
+static char *rcsid = "$Id: arg.c,v 1.45 2005/08/08 19:42:56 abe Exp $";
 #endif
 
 
@@ -272,7 +272,7 @@ ck_file_arg(i, ac, av, fv, rs, sbp)
 #endif	/* defined(HASSPECDEVD) */
 
 		    }
-		    sfp->i = sb.st_ino;
+		    sfp->i = (INODETYPE)sb.st_ino;
 		    sfp->mode = sb.st_mode & S_IFMT;
 		
 #if	defined(CKFA_EXPDEV)
@@ -419,7 +419,7 @@ ck_file_arg(i, ac, av, fv, rs, sbp)
 		Procfsid = pfi;
 
 # if	defined(HASPINODEN)
-		pfi->inode = (unsigned long)sfp->i;
+		pfi->inode = (INODETYPE)sfp->i;
 # endif	/* defined(HASPINODEN) */
 
 	    /*
@@ -524,7 +524,7 @@ ctrl_dcache(c)
 	for (c++; *c && (*c == ' ' || *c == '\t'); c++)
 	    ;
 	if (strlen(c)) {
-	    if (!(DCpathArg = mkstrcpy(c, (MALLOC_S)NULL))) {
+	    if (!(DCpathArg = mkstrcpy(c, (MALLOC_S *)NULL))) {
 		(void) fprintf(stderr, "%s: no space for -D path: ", Pn);
 		safestrprt(c, stderr, 1);
 		Exit(1);
@@ -770,7 +770,7 @@ enter_fd_lst(nm, lo, hi, excl)
 	int excl;			/* exclusion on match */
 {
 	char buf[256], *cp;
-	int dup, n;
+	int n;
 	struct fd_lst *f, *ft;
 /*
  * Don't allow a mixture of exclusions and inclusions.
@@ -1159,7 +1159,7 @@ enter_id(ty, p)
 	char *p;			/* process group ID string pointer */
 {
 	char *cp;
-	int i, id, mx, n;
+	int err, i, id, j, mx, n, ni, nx, x;
 	struct int_lst *s;
 
 	if (!p) {
@@ -1174,11 +1174,15 @@ enter_id(ty, p)
 	case PGID:
 	    mx = Mxpgid;
 	    n = Npgid;
+	    ni = Npgidi;
+	    nx = Npgidx;
 	    s = Spgid;
 	    break;
 	case PID:
 	    mx = Mxpid;
 	    n = Npid;
+	    ni = Npidi;
+	    nx = Npidx;
 	    s = Spid;
 	    break;
 	default:
@@ -1190,12 +1194,19 @@ enter_id(ty, p)
 /*
  * Convert and store the ID.
  */
-	for (cp = p; *cp;) {
+	for (cp = p, err = 0; *cp;) {
 
 	/*
 	 * Assemble ID.
 	 */
-	    for (id = 0; *cp && *cp != ','; cp++) {
+	    for (i = id = x = 0; *cp && *cp != ','; cp++) {
+		if (!i) {
+		    i = 1;
+		    if (*cp == '^') {
+			x = 1;
+			continue;
+		    }
+		}
 
 #if	defined(__STDC__)
 		if (!isdigit((unsigned char)*cp))
@@ -1214,13 +1225,24 @@ enter_id(ty, p)
 	    if (*cp)
 		cp++;
 	/*
-	 * Avoid entering duplicates.
+	 * Avoid entering duplicates and conflicts.
 	 */
-	    for (i = 0; i < n; i++) {
-		if (id == s[i].i)
+	    for (i = j = 0; i < n; i++) {
+		if (id == s[i].i) {
+		    if (x == s[i].x) {
+			j = 1;
+			continue;
+		    }
+		    (void) fprintf(stderr,
+			"%s: P%sID %d has been included and excluded.\n",
+			Pn,
+			(ty == PGID) ? "G" : "",
+			id);
+		    err = j = 1;
 		    break;
+		}
 	    }
-	    if (i < n)
+	    if (j)
 		continue;
 	/*
 	 * Allocate table table space.
@@ -1240,7 +1262,12 @@ enter_id(ty, p)
 		}
 	    }
 	    s[n].f = 0;
-	    s[n++].i = id;
+	    s[n].i = id;
+	    s[n++].x = x;
+	    if (x)
+		nx++;
+	    else
+		ni++;
 	}
 /*
  * Save variables for the type of ID.
@@ -1248,13 +1275,17 @@ enter_id(ty, p)
 	if (ty == PGID) {
 	    Mxpgid = mx;
 	    Npgid = n;
+	    Npgidi = ni;
+	    Npgidx = nx;
 	    Spgid = s;
 	} else {
 	    Mxpid = mx;
 	    Npid = Npuns = n;
+	    Npidi = ni;
+	    Npidx = nx;
 	    Spid = s;
 	}
-	return(0);
+	return(err);
 }
 
 
@@ -1400,7 +1431,10 @@ nwad_exit:
 	    wa++;
 	    if (!*wa || *wa == ':') {
 
+#if	defined(HASIPv6)
 unacc_address:
+#endif	/* defined(HASIPv6) */
+
 		(void) fprintf(stderr,
 		    "%s: unacceptable Internet address in: -i ", Pn);
 		safestrprt(na, stderr, 1);
@@ -1544,7 +1578,7 @@ unacc_port:
 		/*
 		 * Convert service name to port number, using already-specified
 		 * protocol name.  A '-' is taken to be part of the name; hence
-		 * the staring entry of a range can't be a service name.
+		 * the starting entry of a range can't be a service name.
 		 */
 		    for (p = wa; *wa && *wa != ','; wa++)
 			;
@@ -1879,7 +1913,8 @@ enter_uid(us)
 			lnml++;
 		    }
 		    (void) fprintf(stderr,
-			"%s: -u login name > %d characters: ", Pn, LOGINML);
+			"%s: -u login name > %d characters: ", Pn,
+			    (int)LOGINML);
 		    safestrprtn(st, lnml, stderr, 1);
 		    err = j = 1;
 		    break;
@@ -1944,7 +1979,7 @@ enter_uid(us)
 		    continue;
 		}
 		(void) fprintf(stderr,
-		    "%s: UID %d has been included and excluded\n",
+		    "%s: UID %d has been included and excluded.\n",
 			Pn, (int)uid);
 		err = j = 1;
 		break;
