@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.29 2003/03/21 17:41:02 abe Exp $
+ * $Id: dlsof.h,v 1.31 2005/08/08 19:46:38 abe Exp $
  */
 
 
@@ -135,6 +135,10 @@
 #include <sys/vfs.h>
 #include <sys/vmount.h>
 
+# if	defined(HAS_SANFS) && !defined(MNT_SANFS)
+#define	MNT_SANFS	20
+# endif	/* defined(HAS_SANFS) && !defined(MNT_SANFS) */
+
 # if	AIXV>=4100
 #  if	AIXV>=4110
 #undef	u
@@ -320,7 +324,7 @@ extern int ClonePtc;
 struct l_ino {
 	dev_t dev;			/* device */
 	long nlink;			/* link count */
-	ino_t number;			/* inode number */
+	INODETYPE number;		/* inode number */
 	SZOFFTYPE size;			/* file size */
 	unsigned char dev_def;		/* link count is defined */
 	unsigned char nlink_def;	/* link count is defined */
@@ -357,7 +361,7 @@ struct mounts {
 					 * (symbolic links resolved) */
         dev_t dev;              	/* directory st_dev */
 	dev_t rdev;			/* directory st_rdev */
-	ino_t inode;			/* directory st_ino */
+	INODETYPE inode;		/* directory st_ino */
 	u_short mode;			/* directory st_mode */
 	u_short fs_mode;		/* file system st_mode */
 
@@ -385,7 +389,7 @@ struct sfile {
 	u_short mode;			/* S_IFMT mode bits from stat() */
 	int type;			/* file type: 0 = file system
 				 	 *	      1 = regular file */
-	ino_t i;			/* inode number */
+	INODETYPE i;			/* inode number */
 	int f;				/* file found flag */
 	struct sfile *next;		/* forward link */
 };
