@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.20 2004/03/10 23:49:13 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.23 2005/08/08 19:46:38 abe Exp $";
 #endif
 
 
@@ -80,10 +80,26 @@ struct rnode {
 
 #    if	AIXV>4330
 struct rnode64 {
+
+#     if AIXV<5200
 	caddr_t	r_d1[11];		/* dummies; links? */
+#     else /* AIXV>=5200 */
+#      if	AIXV<5300
+	caddr_t	r_d1[12];		/* dummies; links? */
+#      else	/* AIXV>=5300 */
+	caddr_t r_d1[7];		/* dummies; links? */
+#      endif	/* AIXV<5300 */
+#     endif /* AIXV<5200 */
+
 	struct vnode r_vnode;		/* vnode for remote file */
 	struct gnode r_gnode;		/* gnode for remote file */
+
+#     if	AIXV<5300
 	caddr_t r_d2[15];		/* dummies; rnode elements? */
+#     else	/* AIXV>=5300 */
+	caddr_t r_d2[11];		/* dummies; rnode elements? */
+#     endif	/* AIXV<5300 */
+
 	off_t r_size;			/* client's view of file size (long)*/
 	struct vattr r_attr;		/* cached vnode attributes */
 };
@@ -216,6 +232,21 @@ process_node(va)
 # endif	/* AIXA<2 */
 #endif	/* defined(HAS_NFS) */
 
+#if	defined(HAS_SANFS)
+	struct sanfs_node {	/* DEBUG */
+
+	/*
+	 * This is a DEBUG version of the SANFS node structure.  When IBM makes
+	 * the SANFS header files available in /usr/include, this definition
+	 * will be removed.
+	 */
+	    u_long san_d1[20];	/* DEBUG */
+	    struct gnode san_gnode;	/* DEBUG */
+	    u_long san_d2[128];	/* DEBUG */
+	} san;
+	int sans = 0;
+#endif	/* defined(HAS_SANFS) */
+
 #if	AIXV>=4140
 	struct clone *cl;
 	KA_T ka;
@@ -531,28 +562,46 @@ process_clone_again:
 	    }
 	}
 /*
- * Set special node types: NFS; or PROC.
+ * Set special node types: NFS, PROC or SANFS.
  */
 
-#if	defined(HAS_NFS)
+#if	defined(MNT_REMOTE)
 	if (vfs && vfs->vmt_flags & MNT_REMOTE) {
+	    switch(vfs->vmt_gfstype) {
 
-# if	defined(HAS_AFS)
-	    if (!AFSVfsp || (KA_T)v->v_vfsp != AFSVfsp)
-# endif	/* defined(HAS_AFS) */
+# if	defined(HAS_NFS)
+	    case MNT_NFS:
 
-		Ntype = N_NFS;
+#  if	defined(MNT_NFS3)
+	    case MNT_NFS3:
+#  endif	/* defined(MNT_NFS3) */
+
+#  if	defined(MNT_NFS4)
+	    case MNT_NFS4:
+#  endif	/* defined(MNT_NFS4) */
+
+#  if	defined(HAS_AFS)
+		if (!AFSVfsp || (KA_T)v->v_vfsp != AFSVfsp)
+#  endif	/* defined(HAS_AFS) && defined(HAS_NFS) */
+
+		    Ntype = N_NFS;
+# endif	/* defined(HAS_NFS) */
+		break;
+
+# if	defined(HAS_SANFS) && defined(MNT_SANFS)
+	    case MNT_SANFS:
+		Ntype = N_SANFS;
+		break;
+# endif	/* defined(HAS_SANFS) && defined(MNT_SANFS) */
+
+	    }
 	}
-# if	defined(HASPROCFS)
-	else if (vfs && (vfs->vmt_gfstype == MNT_PROCFS))
-	    Ntype = N_PROC;
-# endif	/* defined(HASPROCFS) */
-#else	/* !defined(HAS_NFS) */
-# if	defined(HASPROCFS)
+#endif	/* defined(MNT_REMOTE) */
+
+#if	defined(HASPROCFS)
 	if (vfs && (vfs->vmt_gfstype == MNT_PROCFS))
 	    Ntype = N_PROC;
-# endif	/* defined(HASPROCFS) */
-#endif	/* defined(HAS_NFS) */
+#endif	/* defined(HASPROCFS) */
 
 /*
  * Get the lock status.
@@ -623,6 +672,29 @@ process_clone_again:
 	    break;
 #endif	/* defined(HAS_NFS) */
 
+#if	defined(HAS_SANFS)
+/*
+ * Read SANFS node and associated structures.
+ */
+	case N_SANFS:
+	    if (!g.gn_data
+	    ||  kread((KA_T)g.gn_data, &san, sizeof(san))
+	    ) {
+		(void) snpf(Namech, Namechl, "gnode at %s has no SANFS node",
+		    print_kptr((KA_T)v->v_gnode, (char *)NULL, 0));
+		enter_nm(Namech);
+		return;
+	    }
+	/*
+	 * DEBUG: this code is insufficient.  It can't be completed until IBM
+	 * makes the SANFS header files available in /usr/include.  There are
+	 * apparently two node structures following the SANFS node and file
+	 * attributes (size, etc.) are in the second structure.
+	 */
+	    sans = 1;
+	    break;
+#endif	/* defined(HAS_SANFS) */
+
 /*
  * Read N_REGLR nodes.
  */
@@ -639,7 +711,7 @@ process_clone_again:
 		    return;
 		}
 		(void) zeromem((char *)&i, sizeof(i));
-		i.number = c.cn_inumber;
+		i.number = (INODETYPE)c.cn_inumber;
 		i.size = (off_t)c.cn_size;
 		i.number_def = i.size_def = 1;
 	    /*
@@ -739,6 +811,14 @@ process_clone_again:
 	else
 #endif	/* defined(HASPROCFS) */
 
+#if	defined(HAS_SANFS)
+	if ((Ntype == N_SANFS) && vfs) {
+	    dev = vfs->dev;
+	    devs = 1;
+	}
+	else
+#endif	/* defined(HAS_SANFS) */
+
 	{
 	    if (vfs) {
 		dev = vfs->dev;
@@ -763,7 +843,7 @@ process_clone_again:
 #if	defined(HAS_AFS)
 	case N_AFS:
 	    if (an.ino_st) {
-		Lf->inode = an.inode;
+		Lf->inode = (INODETYPE)an.inode;
 		Lf->inp_ty = 1;
 	    }
 	    break;
@@ -772,12 +852,26 @@ process_clone_again:
 #if	defined(HAS_NFS)
 	case N_NFS:
 	    if (nfss) {
-		Lf->inode = (unsigned long) nfs_attr.va_serialno;
+		Lf->inode = (INODETYPE)nfs_attr.va_serialno;
 		Lf->inp_ty = 1;
 	    }
 	    break;
 #endif	/* defined(HAS_NFS) */
 
+#if	defined(HAS_SANFS)
+	case N_SANFS:
+	    if (sans) {
+	    
+	    /*
+	     * DEBUG: this code is insufficient.  It can't be completed until
+	     * IBM makes the SANFS header files available in /usr/include.
+	     */
+		/* Lf->inode = ???	DEBUG */
+		Lf->inp_ty = 1;
+	    }
+	    break;
+#endif	/* defined(HAS_SANFS) */
+
 # if	AIXV>=3200
 	case N_BLK:
 	case N_CHR:
@@ -787,7 +881,7 @@ process_clone_again:
 
 	case N_REGLR:
 	    if (ins) {
-		Lf->inode = (unsigned long) i.number;
+		Lf->inode = (INODETYPE)i.number;
 		Lf->inp_ty = i.number_def;
 	    }
 	}
@@ -822,6 +916,21 @@ process_clone_again:
 		break;
 #endif	/* defined(HAS_NFS) */
 
+#if	defined(HAS_SANFS)
+	    case N_SANFS:
+		if (sans) {
+
+		/*
+	 	 * DEBUG: this code is insufficient.  It can't be completed
+		 * until IBM makes the SANFS header files available in
+		 * /usr/include.
+		 */
+		    /* Lf->sz = (SZOFFTYPE)???	DEBUG */
+		    Lf->sz_def = 1;
+		}
+		break;
+#endif	/* defined(HAS_SANFS) */
+
 #if	 AIXV>=3200
 	    case N_BLK:
 		if (!Fsize)
@@ -868,6 +977,21 @@ process_clone_again:
 		break;
 #endif	/* defined(HAS_NFS) */
 
+#if	defined(HAS_SANFS)
+	    case N_SANFS:
+		if (sans) {
+
+		/*
+	 	 * DEBUG: this code is insufficient.  It can't be completed
+		 * until IBM makes the SANFS header files available in
+		 * /usr/include.
+		 */
+		    /* Lf->nlink = (long)???	DEBUG */
+		    Lf->nlink_def = 1;
+		}
+		break;
+#endif	/* defined(HAS_SANFS) */
+
 #if	AIXV>=3200
 	    case N_BLK:
 	    case N_CHR:
@@ -1159,7 +1283,7 @@ readlino(ga, li)
 	    return(1);
 	li->dev = i.i_dev;
 	li->nlink = i.i_nlink;
-	li->number = i.i_number;
+	li->number = (INODETYPE)i.i_number;
 	li->size = i.i_size;
 	li->dev_def = li->nlink_def = li->number_def = li->size_def = 1;
 	return(0);
