@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.24 2004/07/06 19:16:20 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.25 2005/08/08 19:46:38 abe Exp $";
 #endif
 
 
@@ -99,7 +99,7 @@ typedef struct so_hash {
 	dev_t dev;			/* device (st_dev) */
 	int nlink;			/* link count (st_nlink) */
 	char *nm;			/* name (mi_name) */
-	unsigned long node;		/* node number (st_ino) */
+	INODETYPE node;			/* node number (st_ino) */
 	struct so_hash *next;		/* next entry in hash bucket */
 	SZOFFTYPE sz;			/* size (st_size) */
 } so_hash_t;
@@ -1021,12 +1021,12 @@ getsoinfo()
 	    sp->nlink = (int)sb.st_nlink;
 	    sp->nm = ln;
 	    ln = (char *)NULL;
-	    sp->node = (unsigned long)sb.st_ino;
+	    sp->node = (INODETYPE)sb.st_ino;
 	    sp->sz = (SZOFFTYPE)sb.st_size;
 	/*
 	 * Link the structure to the appropriate hash bucket.
 	 */
-	    h = SOHASH(sb.st_dev, sb.st_ino);
+	    h = SOHASH(sb.st_dev, (INODETYPE)sb.st_ino);
 	    if (SoHash[h])
 		sp->next = SoHash[h];
 	    else
@@ -1275,7 +1275,7 @@ process_text(pid)
 	so_hash_t *sp;
 	size_t sz;
 	dev_t xdev;
-	unsigned long xnode;
+	INODETYPE xnode;
 	int xs = 0;
 /*
  * Display information on the exec'd entry.
@@ -1332,7 +1332,7 @@ process_text(pid)
 	/*
 	 * Ignore the exec'd and non-regular files.
 	 */
-	    if (xs && (xdev == sb.st_dev) && (xnode == sb.st_ino))
+	    if (xs && (xdev == sb.st_dev) && (xnode == (INODETYPE)sb.st_ino))
 		continue;
 	    if (!S_ISREG(sb.st_mode))
 		continue;
@@ -1343,13 +1343,18 @@ process_text(pid)
 	    alloc_lfile(fd, -1);
 	    Lf->dev_def = Lf->inp_ty = Lf->nlink_def = Lf->sz_def = 1;
 	    Lf->dev = sb.st_dev;
-	    Lf->inode = (unsigned long)sb.st_ino;
+	    Lf->inode = (INODETYPE)sb.st_ino;
 	    (void) snpf(Lf->type, sizeof(Lf->type), "VREG");
 	/*
 	 * Look for a match on device and node numbers in the *.so cache.
 	 */
-	    for (sp = SoHash[SOHASH(sb.st_dev,sb.st_ino)]; sp; sp = sp->next) {
-		if ((sp->dev == sb.st_dev) && (sp->node == sb.st_ino)) {
+	    for (sp = SoHash[SOHASH(sb.st_dev, (INODETYPE)sb.st_ino)];
+		 sp;
+		 sp = sp->next)
+	    {
+		if ((sp->dev == sb.st_dev)
+		&&  (sp->node == (INODETYPE)sb.st_ino))
+		{
 
 		/*
 		 * A match was found; use its name, link count, and size.
