@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: machine.h,v 1.37 2004/07/06 19:16:20 abe Exp $
+ * $Id: machine.h,v 1.40 2005/08/29 10:21:43 abe Exp $
  */
 
 
@@ -251,14 +251,32 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
  * in struct lfile.  The HASLFILEADD definition is a macro that defines
  * them.  If any of the additional elements need to be preset in the
  * alloc_lfile() function of proc.c, the SETLFILEADD macro may be defined
- * to do that.  The HASXOPT definition may be used to select the conditions
- * under which private lfile elements are used.
+ * to do that.
+ *
+ * If any additional elements need to be cleared in alloc_lfile() or in the
+ * free_proc() function of proc.c, the CLRLFILEADD macro may be defined to
+ * do that.  Note that CLRLFILEADD takes one argument, the pointer to the
+ * lfile struct.  The CLRLFILEADD macro is expected to expand to statements
+ * that are complete -- i.e., have terminating semi-colons -- so the macro is
+ * called without a terminating semicolon by proc.c.
+ *
+ * The HASXOPT definition may be used to select the conditions under which
+ * private lfile elements are used.
  */
 
 /* #define HASLFILEADD int ... */
+/* #define CLRLFILEADD(lf)	(lf)->... = (type)NULL;	*/
 /* #define SETLFILEADD Lf->... */
 
 
+/*
+ * HASMNTSTAT indicates the dialect supports the mount stat(2) result option
+ * in its l_vfs and mounts structures.
+ */
+
+/* #define	HASMNTSTAT	1	*/
+
+
 /*
  * HASMNTSUP is defined for those dialects that support the mount supplement
  * option.
@@ -450,10 +468,21 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
 /*
  * HASSETLOCALE is defined for those dialects that have <locale.h> and
  * setlocale().
+ *
+ * If the dialect also has wide character support for language locales,
+ * HASWIDECHAR activates lsof's wide character support and WIDECHARINCL
+ * defines the header file (if any) that must be #include'd to use the
+ * mblen() and mbtowc() functions.
  */
 
 #define	HASSETLOCALE	1
 
+# if	AIXV>=4320
+#define	HASWIDECHAR	1
+# endif	/* AIXV>=4320 */
+
+/* #define	WIDECHARINCL	<wchar.h>	*/
+
 
 /*
  * HASSNODE is defined for those dialects that have snodes.
@@ -551,6 +580,22 @@ typedef	long long	aligned_offset_t  __attribute__ ((aligned (8)));
 #define	HASXOPT_VALUE	0
 
 
+/*
+ * INODETYPE and INODEPSPEC define the internal node number type and its
+ * printf specification modifier.  These need not be defined and lsof.h
+ * can be allowed to define defaults.
+ *
+ * These are defined here, because they must be used in dlsof.h.
+ */
+
+# if	AIXV>=4200
+#define	INODETYPE	unsigned long long
+					/* inode number internal storage type */
+#define	INODEPSPEC	"ll"		/* INODETYPE printf specification
+					 * modifier */
+# endif	/* AIXV>=4200 */
+
+
 /*
  * UID_ARG defines the size of a User ID number when it is passed
  * as a function argument.
