@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.17 2003/10/13 13:28:51 abe Exp $
+ * $Id: dlsof.h,v 1.19 2005/08/08 19:47:20 abe Exp $
  */
 
 
@@ -41,6 +41,7 @@
 #include <stdlib.h>
 #include <dirent.h>
 #include <nlist.h>
+#include <paths.h>
 #include <setjmp.h>
 #include <signal.h>
 #include <string.h>
@@ -171,7 +172,8 @@ typedef	u_long		KA_T;
 #define	READLEN_T	int
 #define STRNCPY_L	size_t
 #define SWAP		"/dev/drum"
-#define	SZOFFTYPE	long long	/* size and offset internal storage
+#define	SZOFFTYPE	unsigned long long
+					/* size and offset internal storage
 					 * type */
 #define	SZOFFPSPEC	"ll"		/* SZOFFTYPE print specification
 					 * modifier */
@@ -209,7 +211,7 @@ struct mounts {
 					 * (symbolic links resolved) */
         dev_t dev;              	/* directory st_dev */
 	dev_t rdev;			/* directory st_rdev */
-	ino_t inode;			/* directory st_ino */
+	INODETYPE inode;		/* directory st_ino */
 	mode_t mode;			/* directory st_mode */
 	mode_t fs_mode;			/* file system st_mode */
         struct mounts *next;    	/* forward link */
@@ -232,7 +234,7 @@ struct sfile {
 	u_short mode;			/* S_IFMT mode bits from stat() */
 	int type;			/* file type: 0 = file system
 				 	 *	      1 = regular file */
-	ino_t i;			/* inode number */
+	INODETYPE i;			/* inode number */
 	int f;				/* file found flag */
 	struct sfile *next;		/* forward link */
 
