@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dsock.c,v 1.17 2004/03/10 23:49:38 abe Exp $";
+static char *rcsid = "$Id: dsock.c,v 1.18 2005/08/08 19:47:20 abe Exp $";
 #endif
 
 
@@ -117,12 +117,13 @@ process_socket(sa)
 #if	defined(HASSOOPT)
 	Lf->lts.ltm = (unsigned int)s.so_linger;
 	Lf->lts.opt = (unsigned int)s.so_options;
+	Lf->lts.pqlen = (unsigned int)s.so_q0len;
 	Lf->lts.qlen = (unsigned int)s.so_qlen;
 	Lf->lts.qlim = (unsigned int)s.so_qlimit;
 	Lf->lts.rbsz = (unsigned long)s.so_rcv.sb_mbmax;
 	Lf->lts.sbsz = (unsigned long)s.so_snd.sb_mbmax;
-	Lf->lts.qlens = Lf->lts.qlims = Lf->lts.rbszs
-		      = Lf->lts.sbszs = (unsigned char)1;
+	Lf->lts.pqlens = Lf->lts.qlens = Lf->lts.qlims = Lf->lts.rbszs
+		       = Lf->lts.sbszs = (unsigned char)1;
 #endif	/* defined(HASSOOPT) */
 
 #if	defined(HASSOSTATE)
