@@ -32,11 +32,16 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.6 2004/03/10 23:50:16 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.7 2005/08/08 19:48:33 abe Exp $";
 #endif
 
 #include "lsof.h"
 
+#include <mach/mach_traps.h>
+#include <mach/mach_init.h>
+#include <mach/message.h>
+#include <mach/vm_map.h>
+
 
 /*
  * Local definitions
@@ -65,7 +70,7 @@ struct phash {
 
 _PROTOTYPE(static pid_t get_parent_pid,(KA_T kpa));
 _PROTOTYPE(static int read_procs,());
-_PROTOTYPE(static void process_map,(KA_T tp));
+_PROTOTYPE(static void process_map,(pid_t pid));
 _PROTOTYPE(static void enter_vn_text,(KA_T va, int *n));
 
 #if	DARWINV>=700
@@ -153,16 +158,21 @@ gather_proc_info()
 	MALLOC_S nb;
 	static struct file **ofb = NULL;
 	static int ofbb = 0;
-	struct proc *p, *pp;
-	struct pcred pc;
-	struct pgrp pg;
-	int pgid, pid;
+	struct proc *p;
+	int pgid;
 	int ppid = 0;
 	static char *pof = (char *)NULL;
 	static int pofb = 0;
 	short pss, sf;
 	int px;
 	uid_t uid;
+
+#if	DARWINV<800
+	struct pcred pc;
+#else	/* DARWINV>=800 */
+	struct ucred uc;
+#endif	/* DARWINV<800 */
+
 /*
  * Read the process table.
  */
@@ -175,10 +185,18 @@ gather_proc_info()
  */
 	for (p = Proc, px = 0; px < Np; p++, px++)
 	{
+
+#if	DARWINV<800
 	    if (!p->p_cred || kread((KA_T)p->p_cred, (char *)&pc, sizeof(pc)))
 		continue;
 	    pgid = pc.p_rgid;
 	    uid = pc.p_ruid;
+#else	/* DARWINV>=800 */
+	    if (!p->p_ucred || kread((KA_T)p->p_ucred, (char *)&uc, sizeof(uc)))
+		continue;
+	    pgid = uc.cr_rgid;
+	    uid = uc.cr_uid;
+#endif	/* DARWINV<800 */
 
 #if	defined(HASPPID)
 	    ppid = get_parent_pid((KA_T)p->p_pptr);
@@ -241,11 +259,9 @@ gather_proc_info()
 		    link_lfile();
 	    }
 	/*
-	 * If there's a task pointer, attempt to use it to process the VM
-	 * map.
+	 * Process the VM map.
 	 */
-	    if (p->task)
-		process_map((KA_T)p->task);
+	    process_map(p->p_pid);
 	/*
 	 * Read open file structure pointers.
 	 */
@@ -424,7 +440,7 @@ get_kernel_access()
 /*
  * Open kernel memory access.
  */
-	if ((Kd = open(Memory ? Memory : KMEM, O_RDONLY, 0)) == NULL)
+	if ((Kd = open(Memory ? Memory : KMEM, O_RDONLY, 0)) < 0)
 	{
 	    (void) fprintf(stderr, "%s: open(%s): %s\n", Pn,
 	        Memory ? Memory : KMEM,
@@ -492,8 +508,16 @@ kread(addr, buf, len)
 {
 	int br;
 
+	if ((off_t)addr & (off_t)0x3) {
+
+	/*
+	 * No read is possible if the address is not aligned on a word
+	 * boundary.
+	 */
+	    return(1);
+	}
 	if (lseek(Kd, (off_t)addr, SEEK_SET) == (off_t)-1)
-	    return(0);
+	    return(1);
 	br = read(Kd, buf, len);
 	return((br == len) ? 0 : 1);
 }
@@ -504,70 +528,77 @@ kread(addr, buf, len)
  */
 
 static void
-process_map(ta)
-	KA_T ta;			/* task address */
+process_map(pid)
+	pid_t pid;			/* process id */
 {
-	int i, n, ne;
-	KA_T ka;
-	struct task {			/* should come from <kern/task.h> */
-	    KA_T Dummy1[5];
-	    KA_T map;
-	} t;
-	struct vm_map_entry {		/* should come from <vm/vm_nap.h> */
-	    KA_T Dummy1;
-	    KA_T vme_next;
-	    KA_T Dummy2[2];
-	    KA_T object;
-	    KA_T Dummy3;
-	    unsigned int
-		is_shared:1,
-		is_sub_map:1;
-	} vme;
-	struct vm_map {			/* should come from <vm/vm_map.h> */
-	    KA_T Dummy1[3];
-	    KA_T vm_next;
-	    KA_T Dummy2[2];
-	    int nentries;
-	} vmm;
-	struct vm_object {
-	    KA_T DUmmy1[12];
-	    KA_T shadow;
-	    KA_T Dummy2[2];
-	    KA_T pager;
-	} vmo, vmso;
-	struct vstruct {		/* should come from <vm/vnode_pager.h>
-					 */
-	    KA_T Dummy1[3];
-	    unsigned int
-		is_swapfile:1;
-	    struct vnode *vs_vp;
-	} vs;
+	vm_address_t address = 0;
+	mach_msg_type_number_t count;
+	vm_region_extended_info_data_t e_info;
+	int n = 0;
+	mach_port_t object_name;
+	vm_size_t size = 0;
+	vm_map_t task;
+	vm_region_top_info_data_t t_info;
+
+	struct vm_object {		/* should come from <vm/vm_object.h> */
+
+#if	DARWINV<800
+	    KA_T		Dummy1[15];
+#else	/* DARWINV>=800 */
+	    KA_T		Dummy1[14];
+#endif	/* DARWINV>=800 */
+
+	    memory_object_t	pager;
+	} vmo;
+
+	struct vnode_pager {		/* from <osfmk/vm/bsd_vm.c> */
+	    KA_T		Dummy1[4];
+	    struct vnode	*vnode;
+	} vp;
+
 /*
- * Read the task structure and its vm_map structure.
+ * Get the task port associated with the process
  */
-	if (!ta || kread(ta, (char *)&t, sizeof(t)))
+	if (task_for_pid((mach_port_name_t)mach_task_self(), pid,
+			 (mach_port_name_t *)&task)
+	!= KERN_SUCCESS) {
 	    return;
-	if (!t.map || kread(t.map, (char *)&vmm, sizeof(vmm)))
-	    return;
-	ne = (vmm.nentries < 1000) ? vmm.nentries: 1000;
+	}
 /*
- * Read vm_map_entry structures.
+ * Go through the task's address space, looking for blocks of memory
+ * backed by an external pager (i.e, a "vnode")
  */
-	for (i = n = 0, ka = vmm.vm_next; ka && (i < ne); i++) {
-	    if (kread(ka, (char *)&vme, sizeof(vme)))
+	for (address = 0;; address += size) {
+	    count = VM_REGION_EXTENDED_INFO_COUNT;
+	    if (vm_region(task, &address, &size, VM_REGION_EXTENDED_INFO,
+			  (vm_region_info_t)&e_info, &count, &object_name)
+	    != KERN_SUCCESS) {
 		break;
-	    ka = vme.vme_next;
-	    if (!vme.object || kread(vme.object, (char *)&vmo, sizeof(vmo)))
+	    }
+	    if (!e_info.external_pager)
 		continue;
-	    if (!vmo.shadow || kread(vmo.shadow, (char *)&vmso, sizeof(vmso)))
+	    count = VM_REGION_TOP_INFO_COUNT;
+	    if (vm_region(task, &address, &size, VM_REGION_TOP_INFO,
+			  (vm_region_info_t)&t_info, &count, &object_name)
+	    != KERN_SUCCESS) {
+		break;
+	    }
+	/*
+	 * The returned "obj_id" is the "vm_object_t" address.
+	 */
+	    if (!t_info.obj_id)
 		continue;
-	    if (!vmso.pager || kread(vmso.pager, (char *)&vs, sizeof(vs)))
+	    if (kread(t_info.obj_id, (char *)&vmo, sizeof(vmo)))
+		break;
+	/*
+	 * If the "pager" is backed by a vnode then the "vm_object_t"
+	 * "memory_object_t" address is actually a "struct vnode_pager *".
+	 */
+	    if (!vmo.pager)
 		continue;
-	    if (vs.is_swapfile || !vs.vs_vp)
-		continue;
-	    if ((unsigned int)vs.vs_vp < 0x100000)	/* !!!Hack!!! */
-		continue;
-	    (void) enter_vn_text((KA_T)vs.vs_vp, &n);
+	    if (kread((KA_T)vmo.pager, (char *)&vp, sizeof(vp)))
+		break;
+	    (void) enter_vn_text((KA_T)vp.vnode, &n);
 	}
 	return;
 }
