@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.25 2003/10/07 14:35:01 abe Exp $
+ * $Id: dlsof.h,v 1.26 2005/08/08 19:56:44 abe Exp $
  */
 
 
@@ -311,7 +311,7 @@ struct l_vfs {
 	char *fsname;			/* file system name */
 
 # if	defined(HASFSINO)
-	ino_t fs_ino;			/* file system inode number */
+	INODETYPE fs_ino;			/* file system inode number */
 # endif	/* defined(HASFSINO) */
 
 	dev_t dev;			/* device number */
@@ -328,7 +328,7 @@ struct mounts {
 					 * (symbolic links resolved) */
 	dev_t dev;              	/* directory st_dev */
 	dev_t rdev;			/* directory st_rdev */
-	ino_t inode;			/* directory st_ino */
+	INODETYPE inode;		/* directory st_ino */
 	mode_t mode;			/* directory st_mode */
 	mode_t fs_mode;			/* file system st_mode */
 	struct mounts *next;    	/* forward link */
@@ -349,7 +349,7 @@ struct sfile {
 	u_short mode;			/* S_IFMT mode bits from stat() */
 	int type;			/* file type: 0 = file system
 				 	 *	      1 = regular file */
-	ino_t i;			/* inode number */
+	INODETYPE i;			/* inode number */
 	int f;				/* file found flag */
 	struct sfile *next;		/* forward link */
 
