@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.21 2003/10/07 14:35:01 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.22 2005/08/08 19:56:44 abe Exp $";
 #endif
 
 
@@ -638,11 +638,11 @@ process_node(va)
 
 #if	ADVFSV>=500
 	    if (fscs) {
-		Lf->inode = (unsigned long)fsc.st.num;
+		Lf->inode = (INODETYPE)fsc.st.num;
 		Lf->inp_ty = 1;
 	    }
 #else	/* ADVFSV<500 */
-	    Lf->inode = (unsigned long)a->a_number;
+	    Lf->inode = (INODETYPE)a->a_number;
 	    Lf->inp_ty = 1;
 #endif	/* ADVFSV>=500 */
 
@@ -657,37 +657,37 @@ process_node(va)
 #endif	/* defined(HASTAGTOPATH) */
 
 	} else if (c) {
-	    Lf->inode = (unsigned long)c->cd_number;
+	    Lf->inode = (INODETYPE)c->cd_number;
 	    Lf->inp_ty = 1;
 	}
 
 #if	DUV>=50000
 	else if (cn) {
 	    if (cn->c_attr.va_mask & AT_NODEID) {
-		Lf->inode = (unsigned long)cn->c_attr.va_fileid;
+		Lf->inode = (INODETYPE)cn->c_attr.va_fileid;
 		Lf->inp_ty = 1;
 	    }
 	}
 #endif	/* DUV>=50000 */
 
 	else if (i) {
-	    Lf->inode = (unsigned long)i->i_number;
+	    Lf->inode = (INODETYPE)i->i_number;
 	    Lf->inp_ty = 1;
 	} else if (p) {
-	    Lf->inode = (unsigned long)((type == VDIR) ? PR_ROOTINO
+	    Lf->inode = (INODETYPE)((type == VDIR) ? PR_ROOTINO
 					: p->prc_pid + PR_INOBIAS);
 	    Lf->inp_ty = 1;
 	} else if (r) {
-	    Lf->inode = (unsigned long)r->r_attr.va_fileid;
+	    Lf->inode = (INODETYPE)r->r_attr.va_fileid;
 	    Lf->inp_ty = 1;
 	} else if (s5) {
-	    Lf->inode = (unsigned long)s5->i_number;
+	    Lf->inode = (INODETYPE)s5->i_number;
 	    Lf->inp_ty = 1;
 	}
 
 #if	DUV>=30000
 	else if (f) {
-	    Lf->inode = (unsigned long)f->fn_fileid;
+	    Lf->inode = (INODETYPE)f->fn_fileid;
 	    Lf->inp_ty = 1;
 	}
 #endif	/* DUV>=30000 */
