@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.35 2004/10/17 21:57:28 abe Exp $
+ * $Id: dlsof.h,v 1.38 2005/08/08 19:49:23 abe Exp $
  */
 
 
@@ -110,7 +110,15 @@
 #include <netinet/tcp_var.h>
 #include <sys/ucred.h>
 #include <sys/uio.h>
+
+# if	defined(HAS_KVM_VNODE)
+#define	_KVM_VNODE
+# endif	/* defined(HAS_KVM_VNODE) */
 #include <sys/vnode.h>
+# if	defined(HAS_KVM_VNODE)
+#undef	_KVM_VNODE
+# endif	/* defined(HAS_KVM_VNODE) */
+
 #include <net/raw_cb.h>
 #include <sys/domain.h>
 #define	pmap	RPC_pmap
@@ -135,6 +143,16 @@
 
 #include <ufs/ufs/inode.h>
 
+# if	defined(HAS_UFS1_2)
+#define	_KERNEL
+struct vop_getextattr_args;
+struct vop_deleteextattr_args;
+struct vop_setextattr_args;
+#include <ufs/ufs/extattr.h>
+#include <ufs/ufs/ufsmount.h>
+#undef	_KERNEL
+# endif	/* defined(HAS_UFS1_2) */
+
 #  if	FREEBSDV>=5010
 #undef	i_devvp
 #  endif	/* FREEBSDV>=5010 */
@@ -355,7 +373,8 @@ typedef	u_long		KA_T;
 #define	READLEN_T	int
 #define STRNCPY_L	size_t
 #define SWAP		"/dev/drum"
-#define	SZOFFTYPE	long long	/* size and offset internal storage
+#define	SZOFFTYPE	unsigned long long
+					/* size and offset internal storage
 					 * type */
 #define	SZOFFPSPEC	"ll"		/* SZOFFTYPE print specification
 					 * modifier */
@@ -399,7 +418,7 @@ struct mounts {
 					 * (symbolic links resolved) */
         dev_t dev;              	/* directory st_dev */
 	dev_t rdev;			/* directory st_rdev */
-	ino_t inode;			/* directory st_ino */
+	INODETYPE inode;		/* directory st_ino */
 	mode_t mode;			/* directory st_mode */
 	mode_t fs_mode;			/* file system st_mode */
         struct mounts *next;    	/* forward link */
@@ -424,12 +443,17 @@ struct sfile {
 	u_short mode;			/* S_IFMT mode bits from stat() */
 	int type;			/* file type: 0 = file system
 				 	 *	      1 = regular file */
-	ino_t i;			/* inode number */
+	INODETYPE i;			/* inode number */
 	int f;				/* file found flag */
 	struct sfile *next;		/* forward link */
 
 };
 
+# if	FREEBSDV==4100 || FREEBSDV==4110
+#define	XDR_VOID	(xdrproc_t)xdr_void
+#define	XDR_PMAPLIST	(xdrproc_t)xdr_pmaplist
+# endif	/* FREEBSDV==4100 || FREEBSDV==4110 */
+
 # if	FREEBSDV>=5000
 #define	XDR_VOID	(const xdrproc_t)xdr_void
 #define	XDR_PMAPLIST	(const xdrproc_t)xdr_pmaplist
