@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dmnt.c,v 1.10 2004/07/06 19:18:57 abe Exp $";
+static char *rcsid = "$Id: dmnt.c,v 1.12 2005/08/08 19:49:23 abe Exp $";
 #endif
 
 
@@ -60,6 +60,114 @@ static char *mnt_names[] = INITMOUNTNAMES;
 #endif	/* FREEBSDV<2000 */
 
 
+#if	FREEBSDV>=5000 && defined(HAS_NO_SI_UDEV)
+/*
+ * dev2udev() -- convert a kernel device number to a user device number
+ */
+
+dev_t
+dev2udev(c)
+	struct cdev *c;
+{
+	char *dn = (char *)NULL;
+	char *ln = (char *)NULL;
+	struct statfs *mb;
+	struct mounts *mtp;
+	int n, sr;
+	static u_int s;
+	struct stat sb;
+	static ss = 0;
+
+	if (ss)
+	    return(c->si_inode ^ s);
+/*
+ * Determine the random udev seed from stat(2) operations on "/" and
+ * its device.
+ */
+	if ((n = getmntinfo(&mb, MNT_NOWAIT)) <= 0) {
+	    (void) fprintf(stderr, "%s: no mount information\n", Pn);
+	    Exit(1);
+	}
+	for (; n; n--, mb++) {
+
+#if	defined(MOUNT_NONE)
+	    if (mb->f_type == MOUNT_NONE || mb->f_type >= MOUNT_MAXTYPE)
+#else	/* !defined(MOUNT_NONE) */
+	    if (!mb->f_type)
+#endif	/* defined(MOUNT_NONE) */
+
+		continue;
+	/*
+	 * Get the real directory name.  Ignore all but the root directory;
+	 * safely stat("/").
+	 */
+	    if (dn)
+		(void) free((FREE_P *)dn);
+	    if (!(dn = mkstrcpy(mb->f_mntonname, (MALLOC_S *)NULL))) {
+
+dev2udev_no_space:
+
+		(void) fprintf(stderr, "%s: no space for mount at ", Pn);
+		safestrprt(mb->f_mntonname, stderr, 0);
+		(void) fprintf(stderr, " (");
+		safestrprt(mb->f_mntfromname, stderr, 0);
+		(void) fprintf(stderr, ")\n");
+		Exit(1);
+	    }
+	    if (!(ln = Readlink(dn))) {
+		if (!Fwarn) {
+		    (void) fprintf(stderr,
+			"      Output information may be incomplete.\n");
+		}
+		continue;
+	    }
+	    if (ln != dn) {
+		(void) free((FREE_P *)dn);
+		dn = ln;
+	    }
+	    ln = (char *)NULL;
+	    if (strcmp(dn, "/"))
+		continue;
+	    if (statsafely(dn, &sb))
+		continue;
+	/*
+	 * Get the real device name and safely stat(2) it.
+	 */
+	    (void) free((FREE_P *)dn);
+	    if (!(dn = mkstrcpy(mb->f_mntfromname, (MALLOC_S *)NULL)))
+		goto dev2udev_no_space;
+	    ln = Readlink(dn);
+	    sr = statsafely(ln, &sb);
+	    if (ln != dn)
+		(void) free((FREE_P *)ln);
+	    ln = (char *)NULL;
+	    (void) free((FREE_P *)dn);
+	    dn = (char *)NULL;
+	    if (sr)
+		continue;
+	    ss = 1;
+	    s = (u_int)sb.st_ino ^ (u_int)sb.st_rdev;
+	    break;
+	}
+/*
+ * Free string copies, as required.
+ */
+	if (dn)
+	    (void) free((FREE_P *)dn);
+	if (ln)
+	    (void) free((FREE_P *)ln);
+/*
+ * If the device seed is known, return its application to the cdev structure's
+ * inode.
+ */
+	if (ss)
+	    return(c->si_inode ^ s);
+	(void) fprintf(stderr, "%s: can't determine user device random seed.\n",	    Pn);
+	Exit(1);
+}
+#endif	/* FREEBSDV>=5000 && defined(HAS_NO_SI_UDEV) */
+
+
 /*
  * readmnt() - read mount table
  */
@@ -69,7 +177,7 @@ readmnt()
 {
 	char *dn = (char *)NULL;
 	char *ln;
-	struct statfs *mb = (struct statfs *)NULL;
+	struct statfs *mb;
 	struct mounts *mtp;
 	int n;
 	struct stat sb;
@@ -188,7 +296,7 @@ no_space_for_mount:
 	    mtp->next = Lmi;
 	    mtp->dev = sb.st_dev;
 	    mtp->rdev = sb.st_rdev;
-	    mtp->inode = sb.st_ino;
+	    mtp->inode = (INODETYPE)sb.st_ino;
 	    mtp->mode = sb.st_mode;
 	/*
 	 * Interpolate a possible file system (mounted-on) device name link.
