@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.32 2004/07/07 13:59:16 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.35 2005/08/08 19:49:23 abe Exp $";
 #endif
 
 
@@ -40,7 +40,7 @@ static char *rcsid = "$Id: dnode.c,v 1.32 2004/07/07 13:59:16 abe Exp $";
 
 
 #if	defined(HASFDESCFS) && HASFDESCFS==1
-_PROTOTYPE(static int lkup_dev_tty,(dev_t *dr, unsigned long *ir));
+_PROTOTYPE(static int lkup_dev_tty,(dev_t *dr, INODETYPE *ir));
 #endif	/* defined(HASFDESCFS) && HASFDESCFS==1 */
 
 
@@ -62,15 +62,14 @@ getmemsz(pid)
 	struct vmspace vm;
 
 	for (n = 0, p = P; n < Np; n++, p++) {
-		if (p->P_PID == pid) {
-			if (!p->P_VMSPACE
-			||  kread((KA_T)p->P_VMSPACE, (char *)&vm, sizeof(vm)))
-				return;
-			Lf->sz = (SZOFFTYPE)ctob(vm.vm_tsize + vm.vm_dsize
-							     + vm.vm_ssize);
-			Lf->sz_def = 1;
-			return;
-		}
+	    if (p->P_PID == pid) {
+		if (!p->P_VMSPACE
+		||  kread((KA_T)p->P_VMSPACE, (char *)&vm, sizeof(vm)))
+		    return;
+		Lf->sz = (SZOFFTYPE)ctob(vm.vm_tsize+vm.vm_dsize+vm.vm_ssize);
+		Lf->sz_def = 1;
+		return;
+	    }
 	}
 }
 # endif	/* defined(HASPROCFS) */
@@ -85,7 +84,7 @@ getmemsz(pid)
 static int
 lkup_dev_tty(dr, ir)
 	dev_t *dr;			/* place to return device number */
-	unsigned long *ir;		/* place to return inode number */
+	INODETYPE *ir;			/* place to return inode number */
 {
 	int i;
 
@@ -106,7 +105,7 @@ lkup_dev_tty_again:
 # endif	/* defined(HASDCACHE) */
 
 		*dr = Devtp[i].rdev;
-		*ir = (unsigned long)Devtp[i].inode;
+		*ir = Devtp[i].inode;
 		return(1);
 	    }
 	}
@@ -193,8 +192,9 @@ process_node(va)
 #if	defined(HAS9660FS)
 	dev_t iso_dev;
 	int iso_dev_def, iso_stat;
-	unsigned long iso_ino, iso_sz;
+	INODETYPE iso_ino;
 	long iso_links;
+	SZOFFTYPE iso_sz;
 #endif	/* defined(HAS9660FS) */
 
 #if	defined(HASFDESCFS)
@@ -202,7 +202,7 @@ process_node(va)
 
 # if	HASFDESCFS==1
 	static dev_t f_tty_dev;
-	static unsigned long f_tty_ino;
+	static INODETYPE f_tty_ino;
 	static int f_tty_s = 0;
 # endif	/* HASFDESCFS==1 */
 
@@ -213,6 +213,13 @@ process_node(va)
 #endif	/* defined(HASFDESCFS) */
 
 #if	FREEBSDV>=5000
+# if	defined(HAS_UFS1_2)
+	int ufst;
+	struct ufsmount um;
+	struct ufs1_dinode d1;
+	struct ufs2_dinode d2;
+# endif	/* !defined(HAS_UFS1_2) */
+
 	struct cdev cd;
 	int cds;
 	struct devfs_dirent de;
@@ -285,8 +292,11 @@ process_overlaid_node:
 #if	FREEBSDV<5000
 	m = (struct mfsnode *)NULL;
 #else	/* FREEBSDV>=5000 */
-	d = (struct devfs_dirent *)NULL;
 	cds = 0;
+	d = (struct devfs_dirent *)NULL;
+# if	defined(HAS_UFS1_2)
+	ufst = 0;
+# endif	/* !defined(HAS_UFS1_2) */
 #endif	/* FREEBSDV<5000 */
 
 #if	defined(HASPROCFS)
@@ -365,12 +375,14 @@ process_overlaid_node:
 	    case VFIFO:
 		Ntype = N_FIFO;
 		break;
+	    default:
+		break;
 	    }
 	}
 
 #if	FREEBSDV>=5000
 /*
- * Get the FreeBSD 5 and above v_rdev structure for VCHR and VBLD vnodes.
+ * For FreeBSD 5 and above VCHR and VBLK vnodes get the v_rdev structure.
  */
 	if (((v->v_type == VCHR) || (v->v_type == VBLK))
 	&&  v->v_rdev
@@ -603,6 +615,20 @@ process_overlaid_node:
 		return;
 	    }
 	    i = &ib;
+
+# if	defined(HAS_UFS1_2)
+	    if (i->i_ump && !kread((KA_T)i->i_ump, (char *)&um, sizeof(um))) {
+		if (um.um_fstype == UFS1) {
+		    if (i->i_din1
+		    &&  !kread((KA_T)i->i_din1, (char *)&d1, sizeof(d1)))
+			ufst = 1;
+		} else {
+		    if (i->i_din2
+		    &&  !kread((KA_T)i->i_din2, (char *)&d2, sizeof(d2)))
+			ufst = 2;
+		}
+	    }
+# endif	/* defined(HAS_UFS1_2) */
 #endif	/* FREEBSDV<2000 */
 
 	    if ((lff = i->i_lockf)) {
@@ -675,7 +701,13 @@ process_overlaid_node:
 #if	FREEBSDV>=4000
 	    if (i->i_dev
 	    &&  !kread((KA_T)i->i_dev, (char *)&si, sizeof(si))) {
+
+# if	defined(HAS_NO_SI_UDEV)
+		dev = dev2udev(&si);
+# else	/* !defined(HAS_NO_SI_UDEV) */
 		dev = si.si_udev;
+# endif	/* defined(HAS_NO_SI_UDEV) */
+
 		devs = 1;
 	    }
 #else	/* FREEBSDV<4000 */
@@ -686,8 +718,24 @@ process_overlaid_node:
 	    if ((type == VCHR) || (type == VBLK)) {
 
 #if	FREEBSDV>=5000
+# if	defined(HAS_UFS1_2)
+		if (ufst == 1) {
+		    rdev = d1.di_rdev;
+		    rdevs = 1;
+		} else if (ufst == 2) {
+		    rdev = d2.di_rdev;
+		    rdevs = 1;
+		} else
+# endif	/* defined(HAS_UFS1_2) */
+
 		if (cds) {
+
+# if	defined(HAS_NO_SI_UDEV)
+		    rdev = dev2udev(&cd);
+# else	/* !defined(HAS_NO_SI_UDEV) */
 		    rdev = cd.si_udev;
+# endif	/* defined(HAS_NO_SI_UDEV) */
+
 		    rdevs = 1;
 		}
 #else	/* FREEBSDV<5000 */
@@ -742,9 +790,28 @@ process_overlaid_node:
 		dev = DevDev;
 		devs = 1;
 	    }
-	    if ((type == VCHR) && cds) {
-		rdev = cd.si_udev;
-		rdevs = 1;
+	    if ((type == VCHR)) {
+
+# if	defined(HAS_UFS1_2)
+		if (ufst == 1) {
+		    rdev = d1.di_rdev;
+		    rdevs = 1;
+		} else if (ufst == 2) {
+		    rdev = d2.di_rdev;
+		    rdevs = 1;
+		} else
+# endif	/* defined(HAS_UFS1_2) */
+
+		if (cds) {
+
+# if	defined(HAS_NO_SI_UDEV)
+		    rdev = dev2udev(&cd);
+# else	/* !defined(HAS_NO_SI_UDEV) */
+		    rdev = cd.si_udev;
+# endif	/* defined(HAS_NO_SI_UDEV) */
+
+		    rdevs = 1;
+		}
 	    }
 	}
 #endif	/* FREEBSDV>=5000 */
@@ -762,10 +829,10 @@ process_overlaid_node:
  * Obtain the inode number.
  */
 	if (i) {
-	    Lf->inode = (unsigned long)i->i_number;
+	    Lf->inode = (INODETYPE)i->i_number;
 	    Lf->inp_ty = 1;
 	} else if (n) {
-	    Lf->inode = (unsigned long)n->n_vattr.va_fileid;
+	    Lf->inode = (INODETYPE)n->n_vattr.va_fileid;
 	    Lf->inp_ty = 1;
 	}
 
@@ -779,7 +846,7 @@ process_overlaid_node:
 #if	defined(HASPROCFS)
 # if	FREEBSDV>=2000
 	else if (p) {
-	    Lf->inode = (unsigned long)p->pfs_fileno;
+	    Lf->inode = (INODETYPE)p->pfs_fileno;
 	    Lf->inp_ty = 1;
 	}
 # endif	/* FREEBSDV>=2000 */
@@ -787,14 +854,14 @@ process_overlaid_node:
 
 #if	defined(HASPSEUDOFS)
 	else if (pnp) {
-	    Lf->inode = (unsigned long)pnp->pn_fileno;
+	    Lf->inode = (INODETYPE)pnp->pn_fileno;
 	    Lf->inp_ty = 1;
 	}
 #endif	/* defined(HASPSEUDOFS) */
 
 #if	FREEBSDV>=5000
 	else if (d) {
-	    Lf->inode = (unsigned long)d->de_inode;
+	    Lf->inode = (INODETYPE)d->de_inode;
 	    Lf->inp_ty = 1;
 	}
 #endif	/* FREEBSDV>=5000 */
@@ -865,6 +932,15 @@ process_overlaid_node:
 	    case N_REGLR:
 		if (type == VREG || type == VDIR) {
 		    if (i) {
+
+#if	defined(HAS_UFS1_2)
+			if (ufst == 1)
+			    Lf->sz = (SZOFFTYPE)d1.di_size;
+			else if (ufst == 2)
+			    Lf->sz = (SZOFFTYPE)d2.di_size;
+			else
+#endif	/* defined(HAS_UFS1_2) */
+
 			Lf->sz = (SZOFFTYPE)i->i_size;
 			Lf->sz_def = 1;
 		    }
@@ -902,7 +978,13 @@ process_overlaid_node:
 		break;
 	    case N_REGLR:
 		if (i) {
+
+#if	defined(HASEFFNLINK)
+		    Lf->nlink = (long)i->HASEFFNLINK;
+#else	/* !defined(HASEFFNLINK) */
 		    Lf->nlink = (long)i->i_nlink;
+#endif	/* defined(HASEFFNLINK) */
+
 		    Lf->nlink_def = 1;
 		}
 
