@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.19 2002/04/29 17:08:26 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.20 2005/08/08 19:50:23 abe Exp $";
 #endif
 
 #if	defined(HPUXKERNBITS) && HPUXKERNBITS>=64
@@ -697,22 +697,22 @@ process_node(va)
 #if	defined(HAS_AFS)
 	case N_AFS:
 	    if (an.ino_st) {
-		Lf->inode = an.inode;
+		Lf->inode = (INODETYPE)an.inode;
 		Lf->inp_ty = 1;
 	    }
 	    break;
 #endif	/* defined(HAS_AFS) */
 
 	case N_MVFS:
-	    Lf->inode = (unsigned long)m.m_ino;
+	    Lf->inode = (INODETYPE)m.m_ino;
 	    Lf->inp_ty = 1;
 	    break;
 	case N_NFS:
 
 #if	HPUXV<1030
-	    Lf->inode = (unsigned long)r.r_nfsattr.na_nodeid;
+	    Lf->inode = (INODETYPE)r.r_nfsattr.na_nodeid;
 #else	/* HPUXV>=1030 */
-	    Lf->inode = (unsigned long)r.r_attr.va_nodeid;
+	    Lf->inode = (INODETYPE)r.r_attr.va_nodeid;
 #endif	/* HPUXV<1030 */
 
 	    Lf->inp_ty = 1;
@@ -720,16 +720,16 @@ process_node(va)
 
 #if	HPUXV>=1000
 	case N_CDFS:
-	    Lf->inode = (unsigned long)c.cd_num;
+	    Lf->inode = (INODETYPE)c.cd_num;
 	    Lf->inp_ty = 1;
 	    break;
 	case N_FIFO:
 	case N_PIPE:
 	    if (vats) {
-		Lf->inode = (unsigned long)vat.va_nodeid;
+		Lf->inode = (INODETYPE)vat.va_nodeid;
 		Lf->inp_ty = 1;
 	    } else {
-		Lf->inode = (unsigned long)v->v_nodeid;
+		Lf->inode = (INODETYPE)v->v_nodeid;
 		Lf->inp_ty = 1;
 	    }
 	    break;
@@ -746,7 +746,7 @@ process_node(va)
 
 # if	HPUXV>=900
 	    if (rns) {
-		Lf->inode = (unsigned long)r.r_nfsattr.na_nodeid;
+		Lf->inode = (INODETYPE)r.r_nfsattr.na_nodeid;
 		Lf->inp_ty = 1;
 		break;
 	    }
@@ -759,7 +759,7 @@ process_node(va)
 	case N_REGLR:
 	case N_SPEC:
 	    if (ins) {
-		Lf->inode = (unsigned long)i.i_number;
+		Lf->inode = (INODETYPE)i.i_number;
 		Lf->inp_ty = 1;
 	    }
 	}
