@@ -128,6 +128,35 @@ _PROTOTYPE(static void ncache_size,(void));
 #endif	/* defined(HASNCACHE) */
 
 
+#if	defined(HASIPv6)
+/*
+ * gethostbyname2() -- an RFC2133-compatible get-host-by-name-two function
+ *                     to get AF_INET and AF_INET6 addresses from host names,
+ *                     using the gethostbyname() and RFC2553-compatible
+ *		       getipnodebyname() functions
+ */
+
+extern struct hostent *
+gethostbyname2(nm, prot)
+	char *nm; 			/* host name */
+	int prot;			/* protocol -- AF_INET or AF_INET6 */
+{
+	int err;
+
+	if (prot == AF_INET) {
+
+	/*
+	 * This shouldn't be necessary if /etc/nsswitch.conf is correct, but
+	 * it's a good fail-safe in case /etc/nsswitch.conf is missing or
+	 * incorrect.
+	 */
+	    return(gethostbyname(nm));
+	}
+	return(getipnodebyname(nm, prot, 0, &err));
+}
+#endif	/* defined(HASIPv6) */
+
+
 /*
  * get_max_fd() -- get maximum file descriptor plus one
  */
@@ -701,7 +730,7 @@ process_finfo(pd, opfid, psfid, na)
 /*
  * Save node number.
  */
-	Lf->inode = (unsigned long)pd->psfd_ino;
+	Lf->inode = (INODETYPE)pd->psfd_ino;
 	Lf->inp_ty = 1;
 /*
  * Save link count.
