@@ -43,6 +43,8 @@ static char *rcsid = "$Id";
  * Local definitions
  */
 
+#define	FDS_ALLOC_INCR	256		/* fds[] allocation increment */
+#define	FDS_ALLOC_INIT	64		/* initial fds[] allocation */
 #define	FINFOINCR	128		/* pst_fileinfo2 table allocation
 					 * increment */
 #define INCLMEM(s, m)	((size_t)(offsetof(struct s, m) \
@@ -107,7 +109,10 @@ struct pstatck {
  * Local static variables
  */
 
-static int HvRtPsfid = 0;		/* 1 if the psfileid of "/" is known */
+static int HvRtPsfid = -1;		/* "/" psfileid status:
+					 *     -1: not yet tested;
+					 *	0: tested and unknown;
+					 *	1: tested and known */
 static struct psfileid RtPsfid;		/* "/" psfileid */
 
 
@@ -120,7 +125,8 @@ _PROTOTYPE(static void process_text,(struct pst_status *p));
 _PROTOTYPE(static struct pst_fileinfo2 *read_files,(struct pst_status *p,
 						    int *n));
 _PROTOTYPE(static struct pst_status *read_proc,(int *n));
-_PROTOTYPE(static struct pst_vm_status *read_vmreg,(struct pst_status *p, int *n));
+_PROTOTYPE(static struct pst_vm_status *read_vmreg,(struct pst_status *p,
+						    int *n));
 
 
 /*
@@ -130,14 +136,40 @@ _PROTOTYPE(static struct pst_vm_status *read_vmreg,(struct pst_status *p, int *n
 void
 gather_proc_info()
 {
+	int cwds, fd, *fds, fdsa, i, j, k, l, nf, np, rtds;
 	struct pst_fileinfo2 *f;
 	long flag;
-	int i, j, nf, np;
 	KA_T ka, na;
+	MALLOC_S nb;
 	struct pst_status *p;
 	struct pst_filedetails pd;
 	struct pst_socket *s;
 	short pss, sf;
+/*
+ * Compute current working and root directory statuses and the statuses of
+ * the first FDS_ALLOC_INIT FDs.
+ */
+	if (Fand && Fdl) {
+	    cwds = (ck_fd_status(CWD, -1) != 2) ? 0 : 1;
+	    rtds = (ck_fd_status(RTD, -1) != 2) ? 0 : 1;
+	    nb = (MALLOC_S)(sizeof(int) * FDS_ALLOC_INIT);
+	    if (!(fds = (int *)malloc(nb))) {
+		(void) fprintf(stderr,
+		    "%s: can't allocate %d FD status entries\n", Pn,
+		    FDS_ALLOC_INIT);
+		Exit(1);
+	    }
+	    for (fdsa = 0; fdsa < FDS_ALLOC_INIT; fdsa++) {
+		if (Fand && Fdl)
+		    fds[fdsa] = (ck_fd_status(NULL, fdsa) == 2) ? 1 : 0;
+		else
+		    fds[fdsa] = 1;
+	    }
+	} else {
+	    cwds = rtds = 1;
+	    fdsa = 0;
+	    fds = (int *)NULL;
+	}
 /*
  * Examine proc structures and their associated information.
  */
@@ -159,16 +191,19 @@ gather_proc_info()
 	/*
 	 * Save current working directory information.
 	 */
-	    if (IS_PSFILEID(&p->pst_cdir) && (p->pst_cdir.psf_fileid > 0)) {
+	    if (cwds
+	    &&  IS_PSFILEID(&p->pst_cdir) && (p->pst_cdir.psf_fileid > 0)
+	    ) {
 		alloc_lfile(CWD, -1);
 		if ((na = read_det(&p->pst_fid_cdir, p->pst_hi_fileid_cdir,
-				   p->pst_lo_fileid_cdir, p->pst_hi_nodeid_cdir,
+				   p->pst_lo_fileid_cdir,
+				   p->pst_hi_nodeid_cdir,
 				   p->pst_lo_nodeid_cdir, &pd)))
-		    (void) process_finfo(&pd, &p->pst_fid_cdir, &p->pst_cdir,
-					 na);
+		    (void) process_finfo(&pd, &p->pst_fid_cdir,
+					 &p->pst_cdir, na);
 		else {
 		    (void) snpf(Namech, Namechl,
-			"can't read%s pst_filedetails%s%s", CWD,
+			"can't read %s pst_filedetails%s%s", CWD,
 			errno ? ": " : "", errno ? strerror(errno) : "");
 		    enter_nm(Namech);
 		}
@@ -178,13 +213,18 @@ gather_proc_info()
 	/*
 	 * Save root directory information.
 	 */
-	    if (IS_PSFILEID(&p->pst_rdir) && (p->pst_rdir.psf_fileid > 0)) {
+	    if (rtds
+	    &&  IS_PSFILEID(&p->pst_rdir) && (p->pst_rdir.psf_fileid > 0)
+	    ) {
+		if (HvRtPsfid < 0)
+		    (void) scanmnttab();
 	 	if (!HvRtPsfid
 		||  memcmp((void *)&RtPsfid, (void *)&p->pst_rdir,
-			   sizeof(RtPsfid)))
+			       sizeof(RtPsfid)))
 		{
 		    alloc_lfile(RTD, -1);
-		    if ((na = read_det(&p->pst_fid_rdir, p->pst_hi_fileid_rdir,
+		    if ((na = read_det(&p->pst_fid_rdir,
+				       p->pst_hi_fileid_rdir,
 				       p->pst_lo_fileid_rdir,
 				       p->pst_hi_nodeid_rdir,
 				       p->pst_lo_nodeid_rdir, &pd)))
@@ -192,8 +232,9 @@ gather_proc_info()
 					     &p->pst_rdir, na);
 		    else {
 			(void) snpf(Namech, Namechl,
-			    "can't read%s pst_filedetails%s%s", RTD,
-			    errno ? ": " : "", errno ? strerror(errno) : "");
+			    "can't read %s pst_filedetails%s%s", RTD,
+			    errno ? ": " : "",
+			    errno ? strerror(errno) : "");
 			enter_nm(Namech);
 		    }
 		    if (Lf->sf)
@@ -208,6 +249,33 @@ gather_proc_info()
 	 * Loop through user's files.
 	 */
 	    for (j = 0, f = read_files(p, &nf); j < nf; j++, f++) {
+		fd = (int)f->psf_fd;
+	    /*
+	     * Check FD status and allocate local file space, as required.
+	     */
+		if (Fand && Fdl && fds) {
+
+		/*
+		 * Check and update the FD status array.
+		 */
+		    if (fd >= fdsa) {
+			for (l = fdsa; l <= fd; l += FDS_ALLOC_INCR)
+			    ;
+			nb = (MALLOC_S)(l * sizeof(int));
+			if (!(fds = (int *)realloc((MALLOC_P *)fds, nb))) {
+			    (void) fprintf(stderr,
+				"%s: can't reallocate %d FD status entries\n",
+				Pn, l);
+			    Exit(1);
+			}
+			while (fdsa < l) {
+			    fds[fdsa] = (ck_fd_status(NULL, fdsa) == 2) ? 1 : 0;
+			    fdsa++;
+			}
+		    }
+		    if (!fds[fd])
+			continue;
+		}
 		alloc_lfile(NULL, (int)f->psf_fd);
 	    /*
 	     * Construct access code.
@@ -388,30 +456,7 @@ get_kernel_access()
 void
 initialize()
 {
-	struct mounts *mp;
-
 	get_kernel_access();
-/*
- * Identify NFS file systems.
- *
- * Compute the psfileid for "/".
- */
-	(void) memset((void *)&RtPsfid, 0, sizeof(RtPsfid));
-	for (HasNFS = 0, mp = readmnt(); mp; mp = mp->next) {
-	    if (mp->MOUNTS_FSTYPE
-	    &&  (strcmp(mp->MOUNTS_FSTYPE, MNTTYPE_NFS) == 0
-	    ||   strcmp(mp->MOUNTS_FSTYPE, MNTTYPE_NFS3) == 0)) {
-		HasNFS = 1;
-		mp->is_nfs = 1;
-	    } else
-		mp->is_nfs = 0;
-	    if (!HvRtPsfid && !strcmp(mp->dir, "/")) {
-		HvRtPsfid = 1;
-		RtPsfid.psf_fsid.psfs_id = mp->dev;
-		RtPsfid.psf_fsid.psfs_type = mp->MOUNTS_STAT_FSTYPE;
-		RtPsfid.psf_fileid = mp->inode;
-	    }
-	}
 }
 
 
@@ -425,10 +470,12 @@ process_text(p)
 {
 	int i, j, nr, ntvu;
 	int meme = 0;
+	static int mems = -1;
 	KA_T na;
 	MALLOC_S nb;
 	static int ntva;
 	struct pst_vm_status *rp;
+	static int txts = -1;
 	struct txtvm {
 	    char *fd;
 	    struct pst_fid opfid;
@@ -437,6 +484,23 @@ process_text(p)
 	    struct pst_filedetails pd;
 	};
 	static struct txtvm *tv = (struct txtvm *)NULL;
+/*
+ * Get and remember "mem" and "txt" FD statuses.
+ */
+	if (mems < 0) {
+	    if (Fand && Fdl)
+		mems = (ck_fd_status("mem", -1) == 2) ? 1 : 0;
+	    else
+		mems = 1;
+	}
+	if (txts < 0) {
+	    if (Fand && Fdl)
+		txts = (ck_fd_status("txt", -1) == 2) ? 1 : 0;
+	    else
+		txts = 1;
+	}
+	if (!mems && !txts)
+	    return;
 /*
  * Pre-allocate sufficient tv[] space for text file.
  */
@@ -456,7 +520,8 @@ no_txtvm_space:
 /*
  * Enter text file in tv[], if possible.
  */
-	if (IS_PSFILEID(&p->pst_text) && (p->pst_text.psf_fileid > 0)) {
+	if (txts && IS_PSFILEID(&p->pst_text) && (p->pst_text.psf_fileid > 0))
+	{
 	    if ((na = read_det(&p->pst_fid_text, p->pst_hi_fileid_text,
 			       p->pst_lo_fileid_text, p->pst_hi_nodeid_text,
 			       p->pst_lo_nodeid_text, &tv[0].pd)))
@@ -481,49 +546,51 @@ no_txtvm_space:
 /*
  * Get unique VM regions.
  */
-	for (i = 0, rp = read_vmreg(p, &nr); i < nr; i++, rp++) {
+	if (mems) {
+	    for (i = 0, rp = read_vmreg(p, &nr); (i < nr); i++, rp++) {
 
-	/*
-	 * Skip duplicate regions.
-	 */
-	    for (j = 0; j < ntvu; j++) {
-		if (memcmp((void *)&rp->pst_id, (void *)&tv[j].psfid,
-			    sizeof(struct psfileid))
-		== 0)
-		    break;
-	    }
-	    if (j < ntvu)
-		continue;
-	/*
-	 * Make sure there's tv[] space for this region.
-	 */
-	    if (ntvu >= ntva) {
-		ntva += TXTVMINCR;
-		nb = (MALLOC_S)(ntva * sizeof(struct txtvm));
-		if (!(tv = (struct txtvm *)realloc((MALLOC_P *)tv, nb)))
-		    goto no_txtvm_space;
-	    }
-	/*
-	 * See if we can read the file details for this region.
-	 */
-	    if ((na = read_det(&rp->pst_fid, rp->pst_hi_fileid,
-			       rp->pst_lo_fileid, rp->pst_hi_nodeid,
-			       rp->pst_lo_nodeid, &tv[ntvu].pd)))
-	    {
-		tv[ntvu].fd = "mem";
-		tv[ntvu].na = na;
-		tv[ntvu].opfid = rp->pst_fid;
-		tv[ntvu].psfid = rp->pst_id;
-		ntvu++;
-	    } else if (!meme) {
-		alloc_lfile("mem", -1);
-		(void) snpf(Namech, Namechl,
-		    "can't read mem pst_filedetails%s%s",
-		    errno ? ": " : "", errno ? strerror(errno) : "");
-		enter_nm(Namech);
-		if (Lf->sf)
-		    link_lfile();
-		meme = 1;
+	    /*
+	     * Skip duplicate regions.
+	     */
+		for (j = 0; j < ntvu; j++) {
+		    if (memcmp((void *)&rp->pst_id, (void *)&tv[j].psfid,
+			       sizeof(struct psfileid))
+		    == 0)
+			break;
+		}
+		if (j < ntvu)
+		    continue;
+	    /*
+	     * Make sure there's tv[] space for this region.
+	     */
+		if (ntvu >= ntva) {
+		    ntva += TXTVMINCR;
+		    nb = (MALLOC_S)(ntva * sizeof(struct txtvm));
+		    if (!(tv = (struct txtvm *)realloc((MALLOC_P *)tv, nb)))
+			goto no_txtvm_space;
+		}
+	    /*
+	     * See if we can read the file details for this region.
+	     */
+		if ((na = read_det(&rp->pst_fid, rp->pst_hi_fileid,
+				   rp->pst_lo_fileid, rp->pst_hi_nodeid,
+				   rp->pst_lo_nodeid, &tv[ntvu].pd)))
+		{
+		    tv[ntvu].fd = "mem";
+		    tv[ntvu].na = na;
+		    tv[ntvu].opfid = rp->pst_fid;
+		    tv[ntvu].psfid = rp->pst_id;
+		    ntvu++;
+		} else if (!meme) {
+		    alloc_lfile("mem", -1);
+		    (void) snpf(Namech, Namechl,
+			"can't read mem pst_filedetails%s%s",
+			errno ? ": " : "", errno ? strerror(errno) : "");
+		    enter_nm(Namech);
+		    if (Lf->sf)
+			link_lfile();
+		    meme = 1;
+		}
 	    }
 	}
 /*
@@ -732,3 +799,39 @@ read_vmreg(p, n)
 	*n = nr;
 	return(reg);
 }
+
+
+/*
+ * scanmnttab() -- scan mount table
+ */
+
+extern void
+scanmnttab()
+{
+	struct mounts *mp;
+/*
+ * Scan the mount table to identify NFS file systems and form the psfileid
+ * for "/".
+ *
+ * This function allows the mount table scan to be deferred until its
+ * information is needed.
+ */
+	if ((HvRtPsfid >= 0) && (HasNFS >= 0))
+	    return;
+	(void) memset((void *)&RtPsfid, 0, sizeof(RtPsfid));
+	for (HasNFS = HvRtPsfid = 0, mp = readmnt(); mp; mp = mp->next) {
+	    if (mp->MOUNTS_FSTYPE
+	    &&  (strcmp(mp->MOUNTS_FSTYPE, MNTTYPE_NFS) == 0
+	    ||   strcmp(mp->MOUNTS_FSTYPE, MNTTYPE_NFS3) == 0)) {
+		HasNFS = 1;
+		mp->is_nfs = 1;
+	    } else
+		mp->is_nfs = 0;
+	    if (!HvRtPsfid && !strcmp(mp->dir, "/")) {
+		HvRtPsfid = 1;
+		RtPsfid.psf_fsid.psfs_id = mp->dev;
+		RtPsfid.psf_fsid.psfs_type = mp->MOUNTS_STAT_FSTYPE;
+		RtPsfid.psf_fileid = mp->inode;
+	    }
+	}
+}
