@@ -46,6 +46,21 @@ static char *rcsid = "$Id";
 _PROTOTYPE(static void printpsproto,(uint32_t p));
 
 
+/*
+ * Local macroes
+ */
+
+#if	defined(HASIPv6)
+
+/*
+ * IPv6_2_IPv4()  -- macro to define the address of an IPv4 address contained
+ *		     in an IPv6 address
+ */
+
+#define IPv6_2_IPv4(v6)	(((uint8_t *)((struct in6_addr *)v6)->s6_addr)+12)
+#endif	/* defined(HASIPv6) */
+
+
 /*
  * printpsproto() -- print PSTAT protocol name
  */
@@ -395,11 +410,11 @@ print_tcptpi(nl)
 # endif	/* defined(PS_SO_PMTU) */
 
 		if (Lf->lts.qlens) {
-		    (void) printf("%cQLEN=%d", sep, Lf->lts.qlen);
+		    (void) printf("%cQLEN=%u", sep, Lf->lts.qlen);
 		    sep = ',';
 		}
 		if (Lf->lts.qlims) {
-		    (void) printf("%cQLIM=%lu", sep, Lf->lts.qlim);
+		    (void) printf("%cQLIM=%u", sep, Lf->lts.qlim);
 		    sep = ',';
 		}
 
@@ -638,6 +653,7 @@ process_socket(f, s)
 	struct sockaddr_in *sa;
 
 #if	defined(HASIPv6)
+	int af;
 	struct sockaddr_in6 *sa6;
 #endif	/* defined(HASIPv6) */
 
@@ -807,12 +823,12 @@ process_socket(f, s)
 	    if ((size_t)s->pst_remaddr_len == sizeof(struct sockaddr_in6)) {
 		sa6 = (struct sockaddr_in6 *)s->pst_remaddr;
 		if ((fp = (int)htons(sa6->sin6_port))
-		||  !IN6_IS_ADDR_UNSPECIFIED(sa6->sin6_addr))
+		||  !IN6_IS_ADDR_UNSPECIFIED(&sa6->sin6_addr))
 		    fa = (unsigned char *)&sa6->sin6_addr;
 	    }
 	    if (la || fa) {
-		if ((la && IN6_IS_ADDR_V4MAPPED(*((struct in6_addr *)la)))
-		||  (fa && IN6_IS_ADDR_V4MAPPED(*((struct in6_addr *)fa))))
+		if ((la && IN6_IS_ADDR_V4MAPPED((struct in6_addr *)la))
+		||  (fa && IN6_IS_ADDR_V4MAPPED((struct in6_addr *)fa)))
 		{
 		    if (la)
 			la = (unsigned char *)IPv6_2_IPv4(la);
@@ -1099,12 +1115,12 @@ process_stream(f)
 	if (dp) {
 	    (void) snpf(Namech, Namechl, "%s", dp->name);
 	    ncx = strlen(Namech);
-	    Lf->inode = (unsigned long)dp->inode;
+	    Lf->inode = (INODETYPE)dp->inode;
 	    Lf->inp_ty = 1;
 	} else {
 	    ncx = (size_t)0;
 	    if (f->psf_id.psf_fileid > 0) {
-		Lf->inode = (unsigned long)f->psf_id.psf_fileid;
+		Lf->inode = (INODETYPE)f->psf_id.psf_fileid;
 		Lf->inp_ty = 1;
 	    }
 	}
