@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: machine.h,v 1.15 2004/03/17 19:12:23 abe Exp abe $
+ * $Id: machine.h,v 1.19 2005/08/29 10:21:48 abe Exp $
  */
 
 
@@ -220,16 +220,34 @@
  * in struct lfile.  The HASLFILEADD definition is a macro that defines
  * them.  If any of the additional elements need to be preset in the
  * alloc_lfile() function of proc.c, the SETLFILEADD macro may be defined
- * to do that.  The HASXOPT definition may be used to select the conditions
- * under which private lfile elements are used.
+ * to do that.
+ *
+ * If any additional elements need to be cleared in alloc_lfile() or in the
+ * free_proc() function of proc.c, the CLRLFILEADD macro may be defined to
+ * do that.  Note that CLRLFILEADD takes one argument, the pointer to the
+ * lfile struct.  The CLRLFILEADD macro is expected to expand to statements
+ * that are complete -- i.e., have terminating semi-colons -- so the macro is
+ * called without a terminating semicolon by proc.c.
+ *
+ * The HASXOPT definition may be used to select the conditions under which
+ * private lfile elements are used.
  */
 
 #define HASLFILEADD struct pst_fid opfid; \
 		    struct psfileid psfid;
+/* #define CLRLFILEADD(lf)	(lf)->... = (type)NULL;	*/
 #define SETLFILEADD memset((void *)&Lf->opfid, 0, sizeof(struct pst_fid)); \
 		    memset((void *)&Lf->psfid, 0, sizeof(struct psfileid));
 
 
+/*
+ * HASMNTSTAT indicates the dialect supports the mount stat(2) result option
+ * in its l_vfs and mounts structures.
+ */
+
+/* #define	HASMNTSTAT	1	*/
+
+
 /*
  * HASMNTSUP is defined for those dialects that support the mount supplement
  * option.
@@ -410,9 +428,16 @@
 /*
  * HASSETLOCALE is defined for those dialects that have <locale.h> and
  * setlocale().
+ *
+ * If the dialect also has wide character support for language locales,
+ * HASWIDECHAR activates lsof's wide character support and WIDECHARINCL
+ * defines the header file (if any) that must be #include'd to use the
+ * mblen() and mbtowc() functions.
  */
 
 #define	HASSETLOCALE	1
+#define	HASWIDECHAR	1
+/* #define	WIDECHARINCL	<wchar.h>	*/
 
 
 /*
@@ -500,6 +525,20 @@
 /* #define	HASXOPT_VALUE	1 */
 
 
+/*
+ * INODETYPE and INODEPSPEC define the internal node number type and its
+ * printf specification modifier.  These need not be defined and lsof.h
+ * can be allowed to define defaults.
+ *
+ * These are defined here, because they must be used in dlsof.h.
+ */
+
+#define	INODETYPE	unsigned long long
+					/* inode number internal storage type */
+#define	INODEPSPEC	"ll"		/* INODETYPE printf specification
+					 * modifier */
+
+
 /*
  * UID_ARG defines the size of a User ID number when it is passed
  * as a function argument.
