@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.14 2004/07/06 19:19:44 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.17 2005/08/29 10:23:33 abe Exp $";
 #endif
 
 
@@ -57,7 +57,7 @@ static char *rcsid = "$Id: dnode.c,v 1.14 2004/07/06 19:19:44 abe Exp $";
 struct llock {
 	int pid;
 	dev_t dev;
-	ino_t inode;
+	INODETYPE inode;
 	char type;
 	struct llock *next;
 };
@@ -91,7 +91,7 @@ check_lock()
 	for (lp = LckH[h]; lp; lp = lp->next) {
 	    if (Lp->pid == lp->pid
 	    &&  Lf->dev == lp->dev
-	    &&  Lf->inode == (unsigned long)lp->inode)
+	    &&  Lf->inode == lp->inode)
 	    {
 		Lf->lock = lp->type;
 		return;
@@ -105,14 +105,19 @@ check_lock()
  */
 
 int
-get_fields(ln, sep, fr)
+get_fields(ln, sep, fr, eb, en)
 	char *ln;			/* input line */
 	char *sep;			/* separator list */
 	char ***fr;			/* field pointer return address */
+	int *eb;			/* indexes of fields where blank may be
+					 * embedded and is not a separator
+					 * (may be NULL) */
+	int en;				/* number of entries in eb[] (may be
+					 * zero) */
 {
 	char *bp, *cp, *sp;
+	int i, j, n;
 	MALLOC_S len;
-	int n;
 	static char **fp = (char **)NULL;
 	static int nfpa = 0;
 
@@ -126,8 +131,22 @@ get_fields(ln, sep, fr)
 		    *cp = '\0';
 		    break;
 		}
-		if (*cp == ' ' || *cp == '\t')
+		if (*cp == '\t')
 		    break;
+		if (*cp == ' ')  {
+		    if (!eb || !en)
+			break;
+		    else {
+			for (i = j = 0; i < en; i++) {
+			    if (eb[i] == n) {
+				j = 1;
+				break;
+			    }
+			}
+			if (!j)
+			    break;
+		    }
+		}
 		if (sep) {
 		    for (sp = sep; *sp; sp++) {
 			if (*sp == *cp)
@@ -174,8 +193,8 @@ get_locks(p)
 	int ex, i, h, mode, pid;
 	unsigned long inode;
 	struct llock *lp, *np;
-	long maj, min;
 	FILE *ls;
+	long maj, min;
 	char type;
 /*
  * Destroy previous lock information.
@@ -208,7 +227,7 @@ get_locks(p)
 	if (!(ls = fopen(p, "r")))
 	    return;
 	while (fgets(buf, sizeof(buf), ls)) {
-	    if (get_fields(buf, ":", &fp) < 10)
+	    if (get_fields(buf, ":", &fp, (int *)NULL, 0) < 10)
 		continue;
 	    if (!fp[1] || strcmp(fp[1], "->") == 0)
 		continue;
@@ -278,7 +297,7 @@ get_locks(p)
 	    for (lp = LckH[h]; lp; lp = lp->next) {
 		if (lp->pid == pid
 		&&  lp->dev == dev
-		&&  lp->inode == inode
+		&&  lp->inode == (INODETYPE)inode
 		&&  lp->type == type)
 		    break;
 	    }
@@ -295,7 +314,7 @@ get_locks(p)
 	    }
 	    lp->pid = pid;
 	    lp->dev = dev;
-	    lp->inode = inode;
+	    lp->inode = (INODETYPE)inode;
 	    lp->type = type;
 	    lp->next = LckH[h];
 	    LckH[h] = lp;
@@ -318,8 +337,7 @@ process_proc_node(p, s, ss, l, ls)
 	int ls;				/* *l status -- i.e., SB_* values */
 {
 	mode_t access, type;
-	char ch, *cp;
-	dev_t dev;
+	char *cp;
 	struct mounts *mp = (struct mounts *)NULL;
 	size_t sz;
 	char *tn;
@@ -369,7 +387,7 @@ process_proc_node(p, s, ss, l, ls)
 		Lf->rdev_def = 1;
 	    }
 	}
-	if (Ntype == N_REGLR && HasNFS) {
+	if (Ntype == N_REGLR && (HasNFS == 2)) {
 	    for (mp = readmnt(); mp; mp = mp->next) {
 		if ((mp->ty == N_NFS)
 		&&  (mp->ds & SB_DEV) && (Lf->dev == mp->dev)
@@ -383,7 +401,7 @@ process_proc_node(p, s, ss, l, ls)
  * Save the inode number.
  */
 	if (ss & SB_INO) {
-	    Lf->inode = (unsigned long)s->st_ino;
+	    Lf->inode = (INODETYPE)s->st_ino;
 	    Lf->inp_ty = 1;
 	}
 /*
