@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.36 2005/05/11 12:53:54 abe Exp $
+ * $Id: dlsof.h,v 1.37 2005/08/08 19:53:24 abe Exp $
  */
 
 
@@ -459,7 +459,8 @@ typedef	u_long		KA_T;
 #define	READLEN_T	int
 #define STRNCPY_L	size_t
 #define SWAP		"/dev/drum"
-#define	SZOFFTYPE	long long	/* size and offset internal storage
+#define	SZOFFTYPE	unsigned long long
+					/* size and offset internal storage
 					 * type */
 #define	SZOFFPSPEC	"ll"		/* SZOFFTYPE print specification
 					 * modifier */
@@ -491,7 +492,7 @@ struct mounts {
 					 * (symbolic links resolved) */
         dev_t dev;              	/* directory st_dev */
 	dev_t rdev;			/* directory st_rdev */
-	ino_t inode;			/* directory st_ino */
+	INODETYPE inode;		/* directory st_ino */
 	mode_t mode;			/* directory st_mode */
 	mode_t fs_mode;			/* file_system st_mode */
         struct mounts *next;    	/* forward link */
@@ -520,7 +521,7 @@ struct sfile {
 	u_short mode;			/* S_IFMT mode bits from stat() */
 	int type;			/* file type: 0 = file system
 				 	 *	      1 = regular file */
-	ino_t i;			/* inode number */
+	INODETYPE i;			/* inode number */
 	int f;				/* file found flag */
 	struct sfile *next;		/* forward link */
 
