@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.38 2004/03/10 23:53:41 abe Exp $
+ * $Id: dlsof.h,v 1.42 2005/08/29 10:24:25 abe Exp $
  */
 
 
@@ -99,11 +99,17 @@
 # endif	/* solaris>=80000 */
 
 # if	defined(HAS_IPCLASSIFIER_H)
+#define	ffs		__kernel_ffs
 #define	inet_ntop	__inet_ntop
 #define	inet_pton	__inet_pton
+#define	longjmp		__kernel_longjmp
+#define	setjmp		__kernel_setjmp
 #include <inet/ipclassifier.h>
+#undef	ffs
 #undef	inet_ntop
 #undef	inet_pton
+#undef	longjmp
+#undef	setjmp
 # endif	/* defined(HAS_IPCLASSIFIER_H) */
 
 #include <inet/ip.h>
@@ -181,6 +187,9 @@
 #undef	vprintf
 #undef	vsnprintf
 #undef	vsprintf
+#include <sys/contract_impl.h>
+#include <sys/ctfs_impl.h>
+#include <sys/port_impl.h>
 #  endif	/* solaris>=100000 */
 
 #include <sys/door.h>
@@ -247,7 +256,23 @@ struct lock_descriptor {
 #include <sys/fs/snode.h>
 #include <sys/fs/tmpnode.h>
 #include <nfs/nfs.h>
+
+# if	solaris>=100000
+#define	_KERNEL
+# endif	/* solaris >= 100000 */
+
 #include <nfs/rnode.h>
+
+#  if	solaris>=100000
+#include <nfs/mount.h>
+#include <nfs/nfs4.h>
+#include <nfs/rnode4.h>
+#  endif	/* solaris>=100000 */
+
+# if	solaris>=100000
+#undef	_KERNEL
+# endif	/* solaris >= 100000 */
+
 #include <sys/proc.h>
 #include <sys/user.h>
 
@@ -348,7 +373,7 @@ typedef	void *		KA_T;
 #define	SZOFFTYPE	unsigned long long
 					/* size and offset internal storage
 					 * type */
-#define	SZOFFPSPEC	"ll"		/* SZOFFTYPE print specification
+#define	SZOFFPSPEC	"ll"		/* SZOFFTYPE printf specification
 					 * modifier */
 # endif	/* solaris>=20501 */
 
@@ -407,9 +432,16 @@ struct l_vfs {
 	dev_t dev;			/* device */
 
 # if	defined(HASFSINO)
-	ino_t fs_ino;			/* file system inode number */
+	INODETYPE fs_ino;		/* file system inode number */
 # endif	/* defined(HASFSINO) */
 
+# if	defined(HASMNTSTAT)
+	unsigned char mnt_stat;		/* mount point stat() status:
+					 *     0 = succeeded
+					 *     1 = failed */
+# endif	/* defined(HASMNTSTAT) */
+
+
 # if	solaris>=80000
 	nlink_t nlink;			/* directory link count */
 	off_t size;			/* directory size */
@@ -427,7 +459,7 @@ struct mounts {
 					 * (symbolic links resolved) */
         dev_t dev;              	/* directory st_dev */
 	dev_t rdev;			/* directory st_rdev */
-	ino_t inode;			/* directory st_ino */
+	INODETYPE inode;		/* directory st_ino */
 	mode_t mode;			/* directory st_mode */
 	mode_t fs_mode;			/* file system st_mode */
         struct mounts *next;    	/* forward link */
@@ -441,6 +473,12 @@ struct mounts {
 	off_t size;			/* directory st_size */
 # endif	/* solaris>=80000 */
 
+# if	defined(HASMNTSTAT)
+	unsigned char stat;		/* mount point stat() status:
+					 *     0 = succeeded
+					 *     1 = failed */
+# endif	/* defined(HASMNTSTAT) */
+
 };
 
 struct pseudo {
@@ -458,7 +496,7 @@ struct sfile {
 	u_short mode;			/* S_IFMT mode bits from stat() */
 	int type;			/* file type: 0 = file system
 				 	 *	      1 = regular file */
-	ino_t i;			/* inode number */
+	INODETYPE i;			/* inode number */
 	int f;				/* file found flag */
 	struct sfile *next;		/* forward link */
 };
@@ -469,10 +507,12 @@ extern int Unof;			/* u_nofiles value */
  * VxFS definitions
  */
 
-#define	VXVOP_FDD	0		/* Vvops[] index for fdd_vnops */
-#define	VXVOP_FDDCH	1		/* Vvops[] index for fdd_chain_vnops */
-#define	VXVOP_REG	2		/* Vvops[] index for vx_vnodeops */
-#define	VXVOP_NUM	3		/* number of Vvops[] entries */
+#define	VXVOP_FCL	0		/* Vvops[] vx_fcl_vnodeops_p index */
+#define	VXVOP_FDD	1		/* Vvops[] fdd_vnops index */
+#define	VXVOP_FDDCH	2		/* Vvops[] fdd_chain_vnops index */
+#define	VXVOP_REG	3		/* Vvops[] vx_vnodeops index */
+#define	VXVOP_REG_P	4		/* Vvops[] vx_vnodeops_p index */
+#define	VXVOP_NUM	5		/* number of Vvops[] entries */
 
 
 /*
