@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.28 2004/03/10 23:53:41 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.32 2005/08/08 19:55:41 abe Exp $";
 #endif
 
 #include "lsof.h"
@@ -50,6 +50,14 @@ static char *rcsid = "$Id: dproc.c,v 1.28 2004/03/10 23:53:41 abe Exp $";
  * Local definitions
  */
 
+#if	defined(__sparc) || defined(__sparcv9)
+#define	ARCH64B	"sparcv9"
+#else	/* !defined(__sparc) && !defined(__sparcv9) */
+# if	defined(__i386) || defined(__amd64)
+#define	ARCH64B	"amd64"
+# endif	/* defined(__i386) || defined(__amd64) */
+#endif	/* defined(__sparc) || defined(__sparcv9) */
+
 #if	solaris>=20501
 #define	KVMHASHBN	8192		/* KVM hash bucket count -- MUST BE
 					 * A POWER OF 2!!! */
@@ -112,7 +120,6 @@ static int Np;				/* number of P[], Pgid[] and Pid[]
 static int Npa = 0;			/* number of P[], Pgid[] and Pid[]
 					 * entries for which space has been
 					 * allocated */
-static KA_T Nproc = 0;			/* kernel's nproc address */
 static struct proc *P = NULL;		/* local proc structure table */
 static int *Pgid = NULL;		/* process group IDs for P[] entries */
 static int *Pid = NULL;			/* PIDs for P[] entries */
@@ -184,7 +191,6 @@ close_kvm()
 void
 gather_proc_info()
 {
-	MALLOC_S bc;
 	static int ft = 1;
 	int i, j;
 	struct proc *p;
@@ -212,12 +218,6 @@ gather_proc_info()
 	struct cred pc;
 #endif	/* solaris>=20500 */
 
-#if	defined(HASFSTRUCT)
-	static int npofb = 0;
-	char *pofp;
-	static char *pofb = (char *)NULL;
-#endif	/* defined(HASFSTRUCT) */
-
 #if	defined(HASZONES)
 	struct zone z;
 	int zh;
@@ -232,30 +232,29 @@ gather_proc_info()
 	    if (get_Nl_value("sgvops", Drive_Nl, &Sgvops) < 0)
 		Sgvops = (KA_T)NULL;
 	    ft = 0;
-	}
+	} else if (!HasALLKMEM) {
+
+	/*
+	 * If not the first time and the ALLKMEM device isn't available, it is
+	 * necessary to close and reopen the KVM device, so that kvm_open()
+	 * will acquire a fresh address for the head of the linked list process
+	 * table.
+	 */
+	    close_kvm();
+	    open_kvm();
 
 #if	solaris>=20501
-	else
-
 	/*
 	 * If not the first time and the ALLKMEM device isn't available,
 	 * re-read the kernel's address space map.
 	 */
-	    if (!HasALLKMEM)
-		readkam((KA_T)NULL);
+	    readkam((KA_T)NULL);
 #endif	/* solaris>=20501 */
 
+	}
 /*
- * Read the linked-list process table.
- *
- * If the system doesn't have the ALLKMEM device, it is necessary to use the
- * KVM library to read the process table.  Since kvm_open() acquires the head
- * of the linked list, it is necssary to call close_kvm() first, so that the
- * read_proc() function's open_kvm() call will cause kvm_open() to acquire a
- * new active chain head address.
+ * Read the process table.
  */
-	if (!HasALLKMEM)
-	    close_kvm();
 	read_proc();
 /*
  * Loop through processes.
@@ -503,7 +502,6 @@ gather_proc_info()
 static void
 get_kernel_access()
 {
-	char er[64];
 	int i;
 	struct stat sb;
 	KA_T v;
@@ -540,7 +538,7 @@ get_kernel_access()
 		Exit(1);
 	    }
 	    for (cp = isa; *cp;) {
-		if (strncmp(cp, "sparcv9", strlen("sparcv9")) == 0) {
+		if (strncmp(cp, ARCH64B, strlen(ARCH64B)) == 0) {
 		    kbits = 64;
 		    break;
 		}
@@ -950,7 +948,8 @@ open_kvm()
 #endif	/* defined(WILLDROPGID) */
 
 	if (!(Kd = kvm_open(Nmlst, Memory, NULL, O_RDONLY, Pn))) {
-	    (void) fprintf(stderr, "%s: kvm_open (namelist=%s, core=%s): %s\n",
+	    (void) fprintf(stderr,
+		"%s: kvm_open(namelist=%s, corefile=%s): %s\n",
 		Pn,
 		Nmlst ? Nmlst : "default",
 		Memory  ? Memory  : "default",
@@ -1063,7 +1062,7 @@ process_text(pa)
 	KA_T pa;			/* address space description pointer */
 {
 	struct as as;
-	int i, j, k, l;
+	int i, j, k;
 	struct seg s;
 	struct segvn_data vn;
 	avl_tree_t *avtp;
@@ -1083,14 +1082,15 @@ process_text(pa)
 /*
  * Loop through the segments.  The loop should stop when the segment
  * pointer returns to its starting point, but just in case, it's stopped
- * when MAXSEGS have been recorded or 2*MAXSEGS have been examined.
+ * when MAXSEGS unique segments have been recorded or 2*MAXSEGS segments
+ * have been examined.
  */
-	avtp = &as.a_segtree;
-
-	for (i = j = k = 0; i < MAXSEGS && j < 2*MAXSEGS; j++) {
-	    if (j == 0 ? get_first_seg(avtp, &s) : get_next_seg(avtp, &s))
+	for (avtp = &as.a_segtree, i = j = 0;
+	     (i < MAXSEGS) && (j < 2*MAXSEGS);
+	     j++)
+	{
+	    if (j ? get_next_seg(avtp, &s) : get_first_seg(avtp, &s))
 		break;
-		
 	    if ((KA_T)s.s_ops == Sgvops && s.s_data) {
 		if (kread((KA_T)s.s_data, (char *)&vn, sizeof(vn)))
 		    break;
@@ -1099,14 +1099,15 @@ process_text(pa)
 		/*
 		 * This is a virtual node segment.
 		 *
-		 * If its vnode pointer has not been seen already,
-		 * print its information.
+		 * If its vnode pointer has not been seen already, record the
+		 * vnode pointer and process the vnode.
 		 */
-		    for (l = 0; l < k; l++) {
-			if (v[l] == (KA_T)vn.vp)
+		    for (k = 0; k < i; k++) {
+			if (v[k] == (KA_T)vn.vp)
 			    break;
 		    }
-		    if (l >= k) {
+		    if (k >= i) {
+			v[i++] = (KA_T)vn.vp;
 			alloc_lfile(" txt", -1);
 
 # if	defined(FILEPTR)
@@ -1114,11 +1115,8 @@ process_text(pa)
 # endif	/* defined(FILEPTR) */
 
 			process_node((KA_T)vn.vp);
-			if (Lf->sf) {
+			if (Lf->sf)
 			    link_lfile();
-			    i++;
-			}
-			v[k++] = (KA_T)vn.vp;
 		    }
 		}
 	    }
@@ -1138,7 +1136,7 @@ process_text(pa)
 	KA_T pa;			/* address space description pointer */
 {
 	struct as as;
-	int i, j, k, l;
+	int i, j, k;
 	struct seg s;
 	struct segvn_data vn;
 	KA_T v[MAXSEGS];
@@ -1157,10 +1155,13 @@ process_text(pa)
 /*
  * Loop through the segments.  The loop should stop when the segment
  * pointer returns to its starting point, but just in case, it's stopped
- * when MAXSEGS have been recorded or 2*MAXSEGS have been examined.
+ * when MAXSEGS unique segments have been recorded or 2*MAXSEGS segments
+ * have been examined.
  */
-	s.s_next = as.a_segs;
-	for (i = j = k = 0; i < MAXSEGS && j < 2*MAXSEGS; j++) {
+	for (s.s_next = as.a_segs, i = j = 0;
+	     i < MAXSEGS && j < 2*MAXSEGS;
+	     j++)
+	{
 	    if (!s.S_NEXT
 	    ||  kread((KA_T)s.S_NEXT, (char *)&s, sizeof(s)))
 		break;
@@ -1172,14 +1173,15 @@ process_text(pa)
 		/*
 		 * This is a virtual node segment.
 		 *
-		 * If its vnode pointer has not been seen already,
-		 * print its information.
+		 * If its vnode pointer has not been seen already, record the
+		 * vnode pointer and process the vnode.
 		 */
-		    for (l = 0; l < k; l++) {
-			if (v[l] == (KA_T)vn.vp)
+		    for (k = 0; k < i; k++) {
+			if (v[k] == (KA_T)vn.vp)
 			    break;
 		    }
-		    if (l >= k) {
+		    if (k >= i) {
+			v[i++] = (KA_T)vn.vp;
 			alloc_lfile(" txt", -1);
 
 # if	defined(FILEPTR)
@@ -1187,11 +1189,8 @@ process_text(pa)
 # endif	/* defined(FILEPTR) */
 
 			process_node((KA_T)vn.vp);
-			if (Lf->sf) {
+			if (Lf->sf)
 			    link_lfile();
-			    i++;
-			}
-			v[k++] = (KA_T)vn.vp;
 		    }
 		}
 	    }
@@ -1275,7 +1274,6 @@ readkam(addr)
 	register int i;
 	register kvmhash_t *kp, *kpp;
 	static KA_T kas = (KA_T)NULL;
-	size_t sz;
 
 	if (addr)
 	    kas = addr;
@@ -1295,7 +1293,7 @@ readkam(addr)
 		{
 		     (void) fprintf(stderr,
 			"%s: no space (%d) for KVM hash buckets\n",
-			Pn, (KVMHASHBN * sizeof(kvmhash_t *)));
+			Pn, (int)(KVMHASHBN * sizeof(kvmhash_t *)));
 		    Exit(1);
 		}
 	    } else if (!addr) {
@@ -1391,7 +1389,7 @@ read_proc()
 	     */
 		if (!PrAct || kread(PrAct, (char *)&paf, sizeof(pa))) {
 		    (void) fprintf(stderr, "%s: can't read practive from %s\n",
-			print_kptr(PrAct, (char *)NULL, 0));
+			Pn, print_kptr(PrAct, (char *)NULL, 0));
 		    Exit(1);
 		}
 		ct = 1;
@@ -1403,7 +1401,6 @@ read_proc()
 	    /*
 	     * Prepare for a proc table scan via the kvm_*proc() functions.
 	     */
-		open_kvm();
 		if (kvm_setproc(Kd) != 0) {
 		    (void) fprintf(stderr, "%s: kvm_setproc: %s\n", Pn,
 			strerror(errno));
@@ -1516,11 +1513,17 @@ read_proc()
 	    }
 	/*
 	 * If not enough processes were saved in the local table, try again.
+	 *
+	 * If the ALLKMEM device isn't available, it is necessary to close and
+	 * reopen the KVM device, so that kvm_open() will acquire a fresh
+	 * address for the head of the linked list process table.
 	 */
 	    if (Np >= PROCMIN)
 		break;
-	    if (!HasALLKMEM)
+	    if (!HasALLKMEM) {
 		close_kvm();
+		open_kvm();
+	    }
 	}
 /*
  * Quit if no proc structures were stored in the local table.
@@ -1704,7 +1707,7 @@ ncache_isroot(va, cp)
 		buf[len++] = '/';
 	    (void) strcpy(&buf[len], cp);
 	    if (statsafely(buf, &sb) != 0
-	    ||  (unsigned long)sb.st_ino != Lf->inode)
+	    ||  (INODETYPE)sb.st_ino != Lf->inode)
 		return(0);
 	}
 /*
@@ -1744,7 +1747,6 @@ ncache_load()
 	static nc_hash_t *khl = (nc_hash_t *)NULL;
 	KA_T kn;
 	static ncache_t *nc = (ncache_t *)NULL;
-	ncache_t ncc;
 	static int Nch = 0;
 	static int nmo = 0;
 	KA_T v;
@@ -1957,7 +1959,7 @@ no_local_space:
 				   (MALLOC_S)(Nla * sizeof(struct l_nch))))
 		    ) {
 			(void) fprintf(stderr,
-			    "%s: can't enlarge local name cache: %s\n", Pn);
+			    "%s: can't enlarge local name cache\n", Pn);
 			Exit(1);
 		    }
 		    lc = &Ncache[n];
@@ -2093,7 +2095,7 @@ ncache_lookup(buf, blen, fp)
 		if (!mtp->dir || !mtp->inode)
 		    continue;
 		if (Lf->dev == mtp->dev
-		&&  (unsigned long)mtp->inode == Lf->inode
+		&&  mtp->inode == Lf->inode
 		&&  strcmp(mtp->dir, Lf->fsdir) == 0)
 		    return(cp);
 	    }
