@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dsock.c,v 1.25 2004/03/10 23:53:41 abe Exp $";
+static char *rcsid = "$Id: dsock.c,v 1.26 2005/08/08 19:55:41 abe Exp $";
 #endif
 
 
@@ -250,7 +250,8 @@ print_tcptpi(nl)
 	    int opt;
 
 	    if ((opt = Lf->lts.opt)
-	    ||  Lf->lts.qlens || Lf->lts.qlims || Lf->lts.rbszs || Lf->lts.sbsz
+	    ||  Lf->lts.pqlens || Lf->lts.qlens || Lf->lts.qlims
+	    ||  Lf->lts.rbszs  || Lf->lts.sbsz
 	    ) {
 		char sep = ' ';
 
@@ -322,12 +323,16 @@ print_tcptpi(nl)
 		}
 # endif	/* defined(SO_OOBINLINE) */
 
+		if (Lf->lts.pqlens) {
+		    (void) printf("%cPQLEN=%u", sep, Lf->lts.pqlen);
+		    sep = ',';
+		}
 		if (Lf->lts.qlens) {
-		    (void) printf("%cQLEN=%d", sep, Lf->lts.qlen);
+		    (void) printf("%cQLEN=%u", sep, Lf->lts.qlen);
 		    sep = ',';
 		}
 		if (Lf->lts.qlims) {
-		    (void) printf("%cQLIM=%lu", sep, Lf->lts.qlim);
+		    (void) printf("%cQLIM=%u", sep, Lf->lts.qlim);
 		    sep = ',';
 		}
 		if (Lf->lts.rbszs) {
@@ -482,7 +487,6 @@ process_socket(sa, ty)
 	char *ty;			/* socket type name */
 {
 	int af;
-	char *cp;
 	unsigned char *fa = (unsigned char *)NULL;
 	int fp = 0;
 	int i, lp;
@@ -899,9 +903,11 @@ process_socket(sa, ty)
 			}
 			if (tc.tcp_oobinline)
 			    Lf->lts.opt |= SO_OOBINLINE;
+			Lf->lts.pqlen = (unsigned int)tc.tcp_conn_req_cnt_q0;
 			Lf->lts.qlen = (unsigned int)tc.tcp_conn_req_cnt_q;
 			Lf->lts.qlim = (unsigned int)tc.tcp_conn_req_max;
-			Lf->lts.qlens = Lf->lts.qlims = (unsigned char)1;
+			Lf->lts.pqlens = Lf->lts.qlens = Lf->lts.qlims
+				       = (unsigned char)1;
 
 # if	solaris>=80000
 #  if	defined(HAS_IPCLASSIFIER_H)
