@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: machine.h,v 1.36 2004/10/17 21:56:28 abe Exp $
+ * $Id: machine.h,v 1.40 2005/08/29 10:22:41 abe Exp $
  */
 
 
@@ -248,15 +248,37 @@ typedef struct aio_req { int dummy; } aio_req_t;
 
 /*
  * HASLFILEADD is defined for those dialects that need additional elements
- * in struct lfile.  The HASLFILEADD definition is a macro that defines
- * them.  If any of the additional elements need to be preset in the
- * alloc_lfile() function of proc.c, the SETLFILEADD macro may be defined
- * to do that.  The HASXOPT definition may be used to select the conditions
- * under which private lfile elements are used.
+ * in struct lfile.  The HASLFILEADD definition is a macro that defines them.
+ *
+ * If any additional elements need to be preset in the alloc_lfile() function
+ * of proc.c, the SETLFILEADD macro may be defined to do that.
+ *
+ * If any additional elements need to be cleared in alloc_lfile() or in the
+ * free_proc() function of proc.c, the CLRLFILEADD macro may be defined to
+ * do that.  Note that CLRLFILEADD takes one argument, the pointer to the
+ * lfile struct.  The CLRLFILEADD macro is expected to expand to statements
+ * that are complete -- i.e., have terminating semi-colons -- so the macro is
+ * called without a terminating semicolon by proc.c.
+ *
+ * The HASXOPT definition may be used to select the conditions under which
+ * private lfile elements are used.
  */
 
-/* #define HASLFILEADD int ... */
-/* #define SETLFILEADD Lf->... */
+# if	solaris>=10000 && defined(HAS_V_PATH)
+#define	HASLFILEADD	KA_T V_path;
+#define	CLRLFILEADD(lf)	(lf)->V_path = (KA_T)NULL;
+#define SETLFILEADD Lf->V_path = (KA_T)NULL;
+# endif	/* solaris>=10000 && defined(HAS_V_PATH) */
+
+
+/*
+ * HASMNTSTAT indicates the dialect supports the mount stat(2) result option
+ * in its l_vfs and mounts structures.
+ */
+
+# if	solaris>=10000 && defined(HAS_V_PATH)
+#define	HASMNTSTAT	1
+# endif	/* solaris>=10000 && defined(HAS_V_PATH) */
 
 
 /*
@@ -285,7 +307,11 @@ typedef struct aio_req { int dummy; } aio_req_t;
  * NCACHELDSFX is a set of C commands to execute after calling ncache_load().
  */
 
+# if	solaris>=10000 && defined(HAS_V_PATH)
+/* #define	HASNCACHE	1	*/
+#else	/* solaris<10 || !defined(HAS_V_PATH) */
 #define	HASNCACHE	1
+# endif	/* solaris>=10000 && defined(HAS_V_PATH) */
 
 #define	NCACHELDPFX	open_kvm();	/* do before calling ncache_load() */
 
@@ -342,6 +368,7 @@ typedef struct aio_req { int dummy; } aio_req_t;
  */
 
 #define	HASPRINTDEV	print_dev
+/* #define	HASPRINTINO	print_ino?	*/
 /* #define	HASPRINTNM	print_nm?	*/
 /* #define	HASPRINTOFF	print_off?	*/
 /* #define	HASPRINTSZ	print_sz?	*/
@@ -370,7 +397,15 @@ typedef struct aio_req { int dummy; } aio_req_t;
  * returns non-zero if it prints a name to stdout.
  */
 
+# if	solaris>=10000 && defined(HAS_V_PATH)
+#define	HASPRIVNMCACHE	print_v_path
+# else	/* solaris<10 || !defined(HAS_V_PATH) */
+#  if	defined(HASVXFSRNL)
+#define	HASPRIVNMCACHE	print_vxfs_rnl_path
+#  else	/* !defined(HASVXFSRNL) */
 /* #define	HASPRIVNMCACHE	<function name>	*/
+#  endif	/* defined(HASVXFSRNL) */
+# endif	/* solaris>=10000 && defined(HAS_V_PATH) */
 
 
 /*
@@ -549,6 +584,22 @@ typedef struct aio_req { int dummy; } aio_req_t;
 /* #define	HASXOPT_VALUE	1 */
 
 
+/*
+ * INODETYPE and INODEPSPEC define the internal node number type and its
+ * printf specification modifier.  These need not be defined and lsof.h
+ * can be allowed to define defaults.
+ *
+ * These are defined here, because they must be used in dlsof.h.
+ */
+
+# if	solaris>=20501
+#define	INODETYPE	unsigned long long
+					/* inode number internal storage type */
+#define	INODEPSPEC	"ll"		/* INODETYPE printf specification
+					 * modifier */
+# endif	/* solaris>=20501 */
+
+
 /*
  * UID_ARG defines the size of a User ID number when it is passed
  * as a function argument.
