@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1996 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.26 2002/10/08 20:18:34 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.27 2005/08/13 16:21:41 abe Exp $";
 #endif
 
 
@@ -768,7 +768,7 @@ get_lock_state:
 	    }
 	    i.dev = nn.nm_vattr.va_fsid;
 	    i.rdev = nn.nm_vattr.va_rdev;
-	    i.number = nn.nm_vattr.va_nodeid;
+	    i.number = (INODETYPE)nn.nm_vattr.va_nodeid;
 	    i.size = nn.nm_vattr.va_size;
 	    if (!nn.nm_mountpt)
 		break;
@@ -811,7 +811,7 @@ get_lock_state:
 	    }
 
 # if	UNIXWAREV>=20102
-	    i.number = (long)pr.pr_ino;
+	    i.number = (INODETYPE)pr.pr_ino;
 	    sd = 0;
 	    if (pr.pr_common
 	    &&  !kread((KA_T)pr.pr_common, (char *)&prc, sizeof(prc))) {
@@ -872,9 +872,9 @@ get_lock_state:
 		sd = 0;
 		pid = 0l;
 		if (v.v_type == VDIR)
-		    i.number = (long)PR_ROOTINO;
+		    i.number = (INODETYPE)PR_ROOTINO;
 		else
-		    i.number = (long)0;
+		    i.number = (INODETYPE)0;
 		break;
 	    }
 	    if (kread((KA_T)pr.pr_proc, (char *)&p, sizeof(p))) {
@@ -895,7 +895,7 @@ get_lock_state:
 	    }
 	    pid = (long)pids.pid_id;
 	    (void) snpf(Namech, Namechl, "/%s/%ld", HASPROCFS, pid);
-	    i.number = pid + PR_INOBIAS;
+	    i.number = (INODETYPE)(pid + PR_INOBIAS);
 	    if (!p.p_as ||  kread((KA_T)p.p_as, (char *)&as, sizeof(as)))
 		sd = 0;
 	    else
@@ -953,7 +953,7 @@ get_lock_state:
 	     * If this is a VCHR stream, look up the device name and record it.
 	     */
 		    if ((dp = findstrdev(&DevDev, (dev_t *)&v.v_rdev))) {
-			Lf->inode = (unsigned long)dp->inode;
+			Lf->inode = dp->inode;
 			Lf->inp_ty = 1;
 			Namech[j++] = ':';
 			k = strlen(dp->name);
@@ -1165,13 +1165,13 @@ get_lock_state:
 	switch (Ntype) {
 
 	case N_NFS:
-	    Lf->inode = (unsigned long)r.r_attr.va_nodeid;
+	    Lf->inode = (INODETYPE)r.r_attr.va_nodeid;
 	    Lf->inp_ty = 1;
 	    break;
 
 #if	defined(HASPROCFS)
 	case N_PROC:
-	    Lf->inode = (unsigned long)i.number;
+	    Lf->inode = i.number;
 	    Lf->inp_ty = 1;
 	    break;
 #endif	/* defined(HASPROCFS) */
@@ -1179,7 +1179,7 @@ get_lock_state:
 	case N_FIFO:
 	    if (!f.fn_realvp) {
 		enter_dev_ch(print_kptr((KA_T)v.v_data, (char *)NULL, 0));
-		Lf->inode = (unsigned long)f.fn_ino;
+		Lf->inode = (INODETYPE)f.fn_ino;
 		Lf->inp_ty = 1;
 		if (f.fn_flag & ISPIPE)
 		    (void) snpf(Namech, Namechl, "PIPE");
@@ -1194,13 +1194,13 @@ get_lock_state:
 	case N_CFS:
 	case N_REGLR:
 	    if (!ni) {
-		Lf->inode = (unsigned long)i.number;
+		Lf->inode = i.number;
 		Lf->inp_ty = (Ntype == N_CFS) ? i.number_def : 1;
 	    }
 	    break;
 	case N_STREAM:
 	    if (sqp && so.lux_dev.size >= 8) {
-		Lf->inode = (unsigned long)so.lux_dev.addr.tu_addr.ino;
+		Lf->inode = (INODETYPE)so.lux_dev.addr.tu_addr.ino;
 		Lf->inp_ty = 1;
 	    }
 	}
@@ -1381,7 +1381,7 @@ get_lock_state:
 		if (Sfile && is_file_named(Namech, 0))
 		    Lf->sf = SELNM;
 		if (so.lux_dev.size >= 8) {
-		    Lf->inode = (unsigned long)so.lux_dev.addr.tu_addr.ino;
+		    Lf->inode = (INODETYPE)so.lux_dev.addr.tu_addr.ino;
 		    Lf->inp_ty = 1;
 		}
 	    }
@@ -1407,7 +1407,7 @@ get_lock_state:
 		    if ((pfi->pid && pid && pfi->pid == (pid_t)pid)
 
 # if	defined(HASPINODEN)
-		    || (Lf->inp_ty == 1 && Lf->inode == pfi->inode)
+		    || ((Lf->inp_ty == 1) && (Lf->inode == pfi->inode))
 # endif	/* defined(HASPINODEN) */
 
 		    ) {
@@ -1490,7 +1490,7 @@ readlino(fx, v, i)
 	    i->nlink = (long)sn.i_nlink;
 	    i->nlink_def = 1;
 	    i->nm = (char *)NULL;
-	    i->number = sn.i_number;
+	    i->number = (INODETYPE)sn.i_number;
 	    i->size = (SZOFFTYPE)sn.i_size;
 	    i->size_def = 1;
 	    return(0);
@@ -1514,7 +1514,7 @@ readlino(fx, v, i)
 		i->nlink_def = 0;
 	    i->nm = (char *)NULL;
 	    if (cn.c_attr.va_mask & AT_NODEID) {
-		i->number = cn.c_attr.va_nodeid;
+		i->number = (INODETYPE)cn.c_attr.va_nodeid;
 		i->number_def = 1;
 	    } else
 		i->number_def = 0;
@@ -1558,7 +1558,7 @@ readlino(fx, v, i)
 	    i->nlink = (long)mn.mno_nlink;
 	    i->nlink_def = 1;
 	    i->nm = (char *)NULL;
-	    i->number = mn.mno_nodeid;
+	    i->number = (INODETYPE)mn.mno_nodeid;
 	    i->number_def = 1;
 	    i->rdev = mn.mno_rdev;
 	    i->rdev = mn.mno_rdev;
