@@ -34,7 +34,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: main.c,v 1.46 2004/07/06 19:09:32 abe Exp $";
+static char *rcsid = "$Id: main.c,v 1.49 2005/08/08 19:43:27 abe Exp $";
 #endif
 
 
@@ -541,7 +541,7 @@ main(argc, argv)
 # endif	/* defined(HASMNTSUP) */
 
 		} else {
-		    (void) fprintf(stderr, "%s: %cm not supported\n", GOp, Pn);
+		    (void) fprintf(stderr, "%s: %cm not supported\n", Pn, GOp);
 		    err = 1;
 		}
 		break;
@@ -816,9 +816,9 @@ main(argc, argv)
 	    Selflags |= SELNFS;
 	if (Funix)
 	    Selflags |= SELUNX;
-	if (Npgid)
+	if (Npgid && Npgidi)
 	    Selflags |= SELPGID;
-	if (Npid)
+	if (Npid && Npidi)
 	    Selflags |= SELPID;
 	if (Nuid && Nuidincl)
 	    Selflags |= SELUID;
@@ -888,6 +888,10 @@ main(argc, argv)
 /*
  * Define the size and offset print formats.
  */
+	(void) snpf(options, sizeof(options), "%%%su", INODEPSPEC);
+	InodeFmt_d = sv_fmt_str(options);
+	(void) snpf(options, sizeof(options), "%%#%sx", INODEPSPEC);
+	InodeFmt_x = sv_fmt_str(options);
 	(void) snpf(options, sizeof(options), "0t%%%su", SZOFFPSPEC);
 	SzOffFmt_0t = sv_fmt_str(options);
 	(void) snpf(options, sizeof(options), "%%%su", SZOFFPSPEC);
@@ -1130,9 +1134,9 @@ main(argc, argv)
 	for (i = 0; i < Npid; i++) {
 
 	/*
-	 * Check process ID specifications.
+	 * Check inclusionary process ID specifications.
 	 */
-	    if (Spid[i].f)
+	    if (Spid[i].f || Spid[i].x)
 		continue;
 	    rv = 1;
 	    if (Fverbose)
@@ -1163,9 +1167,9 @@ main(argc, argv)
 	for (i = 0; i < Npgid; i++) {
 
 	/*
-	 * Check process group ID specifications.
+	 * Check inclusionary process group ID specifications.
 	 */
-	    if (Spgid[i].f)
+	    if (Spgid[i].f || Spgid[i].x)
 		continue;
 	    rv = 1;
 	    if (Fverbose)
