@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: print.c,v 1.45 2004/03/12 14:52:01 abe Exp $";
+static char *rcsid = "$Id: print.c,v 1.46 2005/08/08 19:44:08 abe Exp $";
 #endif
 
 
@@ -982,7 +982,7 @@ print_file()
 #if	defined(HASPRINTINO)
 	    cp = HASPRINTINO(Lf);
 #else	/* !defined(HASPRINTINO) */
-	    (void) snpf(buf, sizeof(buf), "%lu", Lf->inode);
+	    (void) snpf(buf, sizeof(buf), InodeFmt_d, Lf->inode);
 	    cp = buf;
 #endif	/* defined(HASPRINTINO) */
 
@@ -994,7 +994,7 @@ print_file()
 		cp = "";
 	    break;
 	case 3:
-	    (void) snpf(buf, sizeof(buf), "%#lx", Lf->inode);
+	    (void) snpf(buf, sizeof(buf), InodeFmt_x, Lf->inode);
 	    cp = buf;
 	    break;
 	default:
@@ -2604,6 +2604,13 @@ printunkaf(fam, ty)
 	    break;
 #endif	/* defined(AF_USER) */
 
+#if	defined(pseudo_AF_KEY)
+	case pseudo_AF_KEY:
+	    p = "pseudo_";
+	    s = "KEY";
+	    break;
+#endif	/* defined(pseudo_AF_KEY) */
+
 #if	defined(AF_KEY)		/* Security Association DB socket */
 	case AF_KEY:			
 	    s = "KEY";
@@ -2622,6 +2629,12 @@ printunkaf(fam, ty)
 	    break;
 #endif	/* defined(AF_POLICY) */
 
+#if	defined(AF_PPP)		/* PPP socket */
+	case AF_PPP:			
+	    s = "PPP";
+	    break;
+#endif	/* defined(AF_PPP) */
+
 	default:
 	    if (!ty)
 		(void) snpf(Namech, Namechl, "%#x", fam);
