@@ -52,7 +52,7 @@ static char copyright[] =
  */
 
 #define SIGHANDLER_T	void		/* signal handler function type */
-#define	SOCKLEN_T	int		/* socket length type */
+#define	LT_SOCKLEN_T	int		/* socket length type */
 
 
 #if	defined(LT_DIAL_aix)
@@ -60,18 +60,30 @@ static char copyright[] =
  * AIX-specific items
  */
 
-#undef	SOCKLEN_T
-#define	SOCKLEN_T	size_t
+#undef	LT_SOCKLEN_T
+#define	LT_SOCKLEN_T	size_t
 #endif	/* defined(LT_DIAL_aix) */
 
 
+#if	defined(LT_DIAL_darwin)
+/*
+ * Darwin-specific items
+ */
+
+# if	LT_VERS>=800
+#undef	LT_SOCKLEN_T
+#define	LT_SOCKLEN_T	socklen_t
+# endif	/* LT_VERS>=800 */
+#endif	/* defined(LT_DIAL_darwin) */
+
+
 #if	defined(LT_DIAL_ou)
 /*
  * OpenUNIX-specific items
  */
 
-#undef	SOCKLEN_T
-#define	SOCKLEN_T	size_t
+#undef	LT_SOCKLEN_T
+#define	LT_SOCKLEN_T	size_t
 #endif	/* defined(LT_DIAL_ou) */
 
 
@@ -80,8 +92,8 @@ static char copyright[] =
  * UnixWare-specific items
  */
 
-#undef	SOCKLEN_T
-#define	SOCKLEN_T	size_t
+#undef	LT_SOCKLEN_T
+#define	LT_SOCKLEN_T	size_t
 #endif	/* defined(LT_DIAL_uw) */
 
 
@@ -178,7 +190,7 @@ main(argc, argv)
     char *ipaddr;			/* IP address */
     char *pem = (char *)NULL;		/* previous error message */
     char *port;				/* port */
-    SOCKLEN_T sal;			/* socket address length */
+    LT_SOCKLEN_T sal;			/* socket address length */
     char *tcp;				/* temporary character size */
     int ti, tj, tk;			/* temporary indexes */
     int tsfd;				/* temporary socket FD */
@@ -313,7 +325,7 @@ print_errno:
 	ep = "bind";
 	goto print_errno_by_ti;
     }
-    sal = (SOCKLEN_T)sizeof(ca);
+    sal = (LT_SOCKLEN_T)sizeof(ca);
     if (getsockname(Ssock, (struct sockaddr *)&ca, &sal)) {
 	ep = "getsockname";
 	goto print_errno_by_ti;
@@ -364,7 +376,7 @@ print_errno:
  *
  * Replace the server's FD with the accepted one and close the original.
  */
-    sal = (SOCKLEN_T)sizeof(aa);
+    sal = (LT_SOCKLEN_T)sizeof(aa);
     (void) alarm(0);
     (void) signal(SIGALRM, HandleSrvrAlarm);
     (void) alarm(ALARMTM);
@@ -423,7 +435,7 @@ print_errno:
     }
 /*
  * Call lsof three times to find the two sockets: 1) by host name and port;
- * 2)  by IP addressand port ; and 3) by port.
+ * 2) by IP address and port; and 3) by port.
  */
     if ((cem = FindSock(LT_FBYHN)))
 	PrtMsgX(cem, Pn, CleanupSrvr, 1);
